@@ -230,11 +230,11 @@ def _scope_to_environ(scope: dict, body: bytes) -> dict:
     and modified to our needs
     """
     environ = {
-        "REQUEST_METHOD": scope["method"],
+        "REQUEST_METHOD": scope.get("method", ""),
         "SCRIPT_NAME": scope.get("root_path", "").encode("utf8").decode("latin1"),
-        "PATH_INFO": scope["path"].encode("utf8").decode("latin1"),
+        "PATH_INFO": scope.get("path", "").encode("utf8").decode("latin1"),
         "QUERY_STRING": scope["query_string"].decode("ascii"),
-        "SERVER_PROTOCOL": f"HTTP/{scope['http_version']}",
+        "SERVER_PROTOCOL": f"HTTP/{scope.get('http_version', '')}",
         "wsgi.version": (1, 0),
         "wsgi.url_scheme": scope.get("scheme", "http"),
         "wsgi.input": BytesIO(body),
