@@ -9,7 +9,7 @@ from contrast.agent.assess.policy import source_policy
 from contrast.agent.assess.policy import trigger_policy
 from contrast.agent.assess.utils import get_self_for_method
 from contrast.agent.settings import Settings
-from contrast.utils.decorators import fail_safely, log_time
+from contrast.utils.decorators import fail_loudly, log_time
 
 
 def check_or_enter_scope(orig_func):
@@ -33,7 +33,7 @@ def check_or_enter_scope(orig_func):
 
 @check_or_enter_scope  # NOTE: this decorator must come first!
 @log_time("Entering analyze")
-@fail_safely("Failed to perform assess analysis.")
+@fail_loudly("Failed to perform assess analysis.")
 def analyze(context, patch_policy, result, args, kwargs):
     if not context or not Settings().is_assess_enabled():
         return
