@@ -120,12 +120,14 @@ def create_stream_source_event(stream, args, kwargs):
     if context is None:
         return
 
-    if context.stop_source_creation:
-        return
+    source_type = safe_getattr(stream, "cs__source_type", None) or "BODY"
 
     init_event = create_stream_event("source", stream, args, kwargs)
     stream.cs__source_event = init_event
 
+    if context.stop_source_creation(context, source_type, None):
+        return
+
     if len(args) > 0:
         properties = get_properties(args[0])
         if properties is not None:
