@@ -3,6 +3,7 @@
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.assess.utils import get_properties
 from contrast.agent.assess.policy.propagators.base_propagator import BasePropagator
+from contrast.agent.policy.patch_manager import is_patched
 from contrast.utils.decorators import fail_quietly
 
 from contrast.extern import structlog as logging
@@ -32,7 +33,6 @@ class DBWritePropagator(BasePropagator):
         We need to check if any of the values are tracked strings. If so, we save
         all relevant information to be used in propagate().
         """
-        from contrast.agent.policy.applicator import build_method_name
 
         self.new_column_sources = {}
         cls = self.preshift.obj.__class__
@@ -42,8 +42,7 @@ class DBWritePropagator(BasePropagator):
             if not value:
                 continue
 
-            cs_method_name = build_method_name(col_name)
-            if hasattr(cls, cs_method_name):
+            if is_patched(getattr(cls, col_name, None)):
                 continue
 
             col_value_properties = get_properties(value)
