@@ -47,7 +47,7 @@ class JsonPropagator(BasePropagator):
 
         if isinstance(item, SUPPORTED_TYPES):
             if is_tracked(item):
-                self.apply_tags(item)
+                self._apply_tags(item)
         elif isinstance(item, dict):
             for key, value in item.items():
                 self._propagate(key)
@@ -56,11 +56,13 @@ class JsonPropagator(BasePropagator):
             for it in safe_iterator(item):
                 self._propagate(it)
 
-    def apply_tags(self, item):
+    def _apply_tags(self, item):
         """
         Transfer all items from the item to the target, our result
         :param item: value from the dict
-        :return:
+
+        This is a private method and does not overload the base `apply_tags`
+        method as it doesn't require the same args.
         """
         target = self.target
 
