@@ -7,7 +7,7 @@ from contrast.agent.policy import constants
 from contrast.agent.assess.assess_exceptions import ContrastAssessException
 from contrast.agent.policy.policy_node import PolicyNode
 from contrast.agent.settings import Settings
-from contrast.api.dtm_pb2 import TraceEvent
+from contrast.api.trace_event import TraceEvent
 from contrast.utils.string_utils import equals_ignore_case
 
 
@@ -85,7 +85,7 @@ class SourceNode(PolicyNode):
         and also Type refers to input type, like parameter, so we have to call
         this node_type. :-/
         """
-        return TraceEvent.TYPE_PROPAGATION
+        return TraceEvent.EventType.TYPE_PROPAGATION
 
     def should_apply(self):
         if equals_ignore_case(self.version, self.ALL) or not self.package:
