@@ -43,6 +43,22 @@ def apply(
                     self_obj, ret, args, orig_kwargs
                 )
 
+                if not possible_sources:
+                    if not rule.dataflow:
+                        cs__apply_trigger(
+                            context,
+                            rule,
+                            node,
+                            None,
+                            self_obj,
+                            ret,
+                            None,
+                            args,
+                            orig_kwargs,
+                        )
+
+                    return
+
                 for source in possible_sources:
                     if isinstance(source, dict):
                         for key, value in source.items():
@@ -94,16 +110,3 @@ def apply(
                             args,
                             orig_kwargs,
                         )
-                else:
-                    if not rule.dataflow:
-                        cs__apply_trigger(
-                            context,
-                            rule,
-                            node,
-                            None,
-                            self_obj,
-                            ret,
-                            None,
-                            args,
-                            orig_kwargs,
-                        )
