@@ -28,8 +28,8 @@ def _get_route_for_hash(context):
         3. Raw uri
     """
     route = context.current_route
-    if route is not None and route.route:
-        return route.route
+    if route is not None and route.signature:
+        return route.signature
 
     normalized_uri = context.request.get_normalized_uri()
     return normalized_uri or context.request.path_qs
@@ -50,7 +50,7 @@ def update_preflight_hashes(context):
 
     @param context: Current request context
     """
-    for finding in context.activity.findings:
+    for finding in context.findings:
         hasher = Digest()
         hasher.update(finding.hash_code)
 
