@@ -15,7 +15,7 @@ from contrast.agent.assess.tag import (
     WITHIN,
     WITHOUT,
 )
-from contrast.api.dtm_pb2 import TraceTaintRange
+from contrast.api.trace_event import TraceTaintRange
 from contrast.utils.assess.tag_utils import merge_tags, ordered_merge
 from contrast.utils.string_utils import protobuf_safe
 
@@ -299,7 +299,7 @@ class Properties(object):
         """
         Build ContrastEvent from an applied policy method
 
-        After creation of the ContrastEvent, report the event to the ObservedRoute in the RequestContext
+        After creation of the ContrastEvent, report the event to the observed_route in the RequestContext
         """
         event = ContrastEvent(
             policy_node,
