@@ -17,7 +17,7 @@ class BaseConfigRule(StaticRule):
         settings = Settings()
 
         properties = {}
-        properties[self.SESSION_ID] = settings.config.get_session_id()
+        properties[self.SESSION_ID] = settings.config.session_id
         properties[self.PATH] = config_path
         properties[self.SNIPPET] = self.get_snippet(value)
         return properties
