@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from datetime import timedelta
 
@@ -21,4 +21,10 @@ class SessionAgeRuleMixin(object):
         if isinstance(value, timedelta):
             return value > timedelta(minutes=30)
 
+        if isinstance(value, str):
+            try:
+                value = int(value)
+            except ValueError:
+                pass
+
         return value is None or value > 30 * 60
