@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.extern.six import binary_type, string_types, text_type
-
 from contrast.agent.assess.rules.providers.hardcoded_value_rule import (
     HardcodedValueRule,
 )
@@ -33,4 +31,4 @@ class HardcodedKey(HardcodedValueRule):
         if not value:
             return False
 
-        return isinstance(value, (binary_type, string_types, text_type, bytearray))
+        return isinstance(value, (bytes, str, bytearray))
