@@ -119,10 +119,6 @@ class HardcodedValueRule(StaticRule, CodeParserMixin):
             properties, source_name=source_name, constant=constant
         )
 
-    def add_events_to_finding(self, finding, **kwargs):
-        # Hardcoded provider rules do not have events to add to a finding
-        pass
-
     @property
     def redacted_marker(self):
         return " = [**REDACTED**]"
