@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.api import Finding
+from contrast.api import Finding, send_finding
 from contrast.agent.assess.rules.base_rule import BaseRule
 
 
@@ -32,13 +32,13 @@ class BaseResponseRule(BaseRule):
             )
         )
 
-    def add_events_to_finding(self, finding, **kwargs):
-        # Response rules do not have events to add to a finding
-        pass
-
     def update_preflight_hash(self, hasher, **kwargs):
         # Response rules do not update the hash
         pass
 
     def create_finding(self, properties):
         return Finding(self, properties)
+
+    def build_and_append_finding(self, properties, context):
+        finding = self.create_finding(properties)
+        send_finding(finding, context)
