@@ -14,8 +14,8 @@ class StaticRule(BaseRule):
     """
 
     def build_and_send_finding(self, properties, **kwargs):
-        finding_msg = Finding(self, properties, **kwargs)
-        finding_msg.version = Finding.pick_version(finding_msg)
+        finding = Finding(self, properties, **kwargs)
+        finding.set_version()
 
         self.finding_reported()
-        send_finding(finding_msg)
+        send_finding(finding)
