@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
+import contrast
+
 from contrast.agent.policy import constants
 from contrast.agent.assess.assess_exceptions import ContrastAssessException
 from contrast.agent.policy.trigger_node import TriggerNode
@@ -33,6 +35,7 @@ class TriggerRule(BaseRule):
 
     def __init__(self, name, dataflow, disallowed_tags=None, required_tags=None):
         self._name = name
+
         self.dataflow = dataflow
         self.nodes = []
 
@@ -48,6 +51,22 @@ class TriggerRule(BaseRule):
     def name(self):
         return self._name
 
+    @property
+    def disabled(self):
+        """
+        Property indicating whether rule is disabled
+        """
+        if super(TriggerRule, self).disabled:
+            return True
+
+        ctx = contrast.CS__CONTEXT_TRACKER.current()
+        if ctx is None:
+            return False
+
+        return bool(
+            ctx.excluded_assess_rules and self.name in ctx.excluded_assess_rules
+        )
+
     @cached_property
     def loud_name(self):
         return str(self.name.upper().replace("-", "_"))
@@ -143,12 +162,12 @@ class TriggerRule(BaseRule):
         return Finding(self, properties, **kwargs)
 
     def build_and_append_finding(self, context, properties, node, target, **kwargs):
-        finding_msg = self.create_finding(properties, node, target, **kwargs)
+        finding = self.create_finding(properties, node, target, **kwargs)
 
         # if after creating the finding, we discover that this finding already exists
         # in context.activity, then do not add it and return early
-        for curr_finding in context.activity.findings:
-            if finding_msg.hash_code == curr_finding.hash_code:
+        for curr_finding in context.findings:
+            if finding.hash_code == curr_finding.hash_code:
                 return
 
         logger.debug(
@@ -159,7 +178,7 @@ class TriggerRule(BaseRule):
         )
 
         self.finding_reported()
-        send_finding(finding_msg, context)
+        send_finding(finding, context)
 
     JSON_NAME = "name"
     JSON_DISALLOWED_TAGS = "disallowed_tags"
