@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.api.dtm_pb2 import TraceTaintRange
+from contrast.api.trace_event import TraceTaintRange
 from contrast.utils.assess.tag_utils import merge_tags
 from contrast.agent.assess.tag import Tag
 
