@@ -51,8 +51,8 @@ class DiscoverablePackage(object):
             # calls on our re_patch and attempts to re-initialize this class.
             try:
                 return pkg_resources.get_distribution(framework_name)
-            except Exception as err:
-                return err
+            except Exception:
+                return None
 
     def discover_server(self):
         """
