@@ -13,8 +13,9 @@ from contrast.agent import (
     service_client,
     scope,
     thread_watcher,
-    agent_lib_manager,
 )
+from contrast.agent import agent_lib
+from contrast.agent.protect import input_analysis
 from contrast.agent.request_context import RequestContext
 from contrast.agent.assess.rules.response.xss import analyze_xss
 from contrast.agent.assess.rules.response.analyze import analyze_response_rules
@@ -23,20 +24,23 @@ from contrast.agent.assess.rules.providers.enable import enable_providers
 from contrast.agent.middlewares.route_coverage.routes_mixin import RoutesMixin
 from contrast.agent.settings import Settings
 from contrast.agent.speedracer_input_analysis import get_input_analysis
-from contrast.api.dtm_pb2 import AttackResult
+from contrast.api.attack import ProtectResponse
 from contrast.reporting import ReportingClient
+from contrast.reporting.activity_masker import ActivityMasker
 from contrast.utils.decorators import cached_property
 from contrast.utils.exceptions.contrast_service_exception import (
     ContrastServiceException,
 )
 from contrast.utils.decorators import log_time_cm
 from contrast.utils.exceptions.security_exception import SecurityException
-from contrast.utils import inventory_utils
 from contrast.utils.library_reader.library_reader import LibraryReader
 from contrast.utils.loggers.logger import setup_agent_logger, setup_basic_agent_logger
 from contrast.utils.timer import now_ms_float, now_ms
 from contrast.utils.decorators import fail_loudly, fail_quietly
 from contrast.assess_extensions import cs_str
+from contrast.agent.protect.rule.sqli_rule import SqlInjection
+from contrast.agent.protect.rule.cmdi_rule import CmdInjection
+from contrast.agent.protect.rule.base_rule import BaseRule
 
 if not contrast.telemetry_disabled():
     from contrast.agent.telemetry import Telemetry
@@ -133,6 +137,11 @@ class BaseMiddleware(RoutesMixin):
                 )
                 return
 
+        # This MUST happen after the initialization calls for Service and/or TeamServer messaging
+        # (sending server start and application start) to ensure that TeamServer will accept the
+        # messages sent by our background reporting threads
+        thread_watcher.ensure_running(self)
+
         if not BaseMiddleware._loaded:
             self.initialize_libraries()
 
@@ -152,7 +161,7 @@ class BaseMiddleware(RoutesMixin):
             self.settings.config.is_agent_lib_enabled
             and self.settings.is_protect_enabled()
         ):
-            agent_lib_manager.initialize()
+            agent_lib.initialize()
         else:
             logger.debug("Not using agent-lib")
 
@@ -270,14 +279,10 @@ class BaseMiddleware(RoutesMixin):
         # Passing callback to send message due to a circular import issue, and a
         # deadlock occurring if something is imported inside of a function running in
         # this thread
-        send_message_func = (
-            self.reporting_client.add_message
-            if self.settings.config.is_service_bypassed
-            else service_client.send_messages
-        )
-
         self.library_reader = LibraryReader(
-            self.settings, send_message_func=send_message_func
+            self.settings,
+            send_sr_message_func=service_client.send_messages,
+            send_ts_message_func=self.reporting_client.add_message,
         )
         self.library_reader.start_library_analysis_thread()
 
@@ -330,13 +335,16 @@ class BaseMiddleware(RoutesMixin):
             logger.debug("Will not analyze request: agent disabled.")
             return False
 
-        if self.settings.ignore_request(self.request_path):
+        context = RequestContext(environ)
+
+        path = environ.get("PATH_INFO")
+
+        if self.settings.evaluate_exclusions(context, path):
             logger.debug("Will not analyze request: request meets exclusions.")
             return False
 
         from contrast.agent.assess import sampling
 
-        context = RequestContext(environ)
         if sampling.enabled() and sampling.meets_criteria(context):
             logger.debug("Will not analyze request: request meets sampling.")
             return False
@@ -365,13 +373,16 @@ class BaseMiddleware(RoutesMixin):
 
             context.truncate_request_body()
 
-            if self.settings.config.is_service_bypassed:
-                for msg in self.final_ts_messages(context):
-                    self.reporting_client.add_message(msg)
-            else:
-                # messages now sent directly to TS
-                self.reporting_client.add_message(teamserver_messages.ServerActivity())
+            for msg in self.final_ts_messages(context):
+                self.reporting_client.add_message(msg)
 
+            # Mask sensitive data with activity masker
+            # takes context.activity goes through http_request for activity
+            # and masks body, cookies, headers, query and request parameters
+            ActivityMasker(context).mask_sensitive_data()
+            self.reporting_client.add_message(teamserver_messages.Activity(context))
+
+            if not self.settings.config.is_service_bypassed:
                 # messages still sent to SR until transition.
                 final_messages = self.final_messages(context)
                 service_client.send_messages(final_messages)
@@ -379,10 +390,13 @@ class BaseMiddleware(RoutesMixin):
         self.first_request = False
 
     def final_ts_messages(self, context):
+        """
+        Messages sent to TS every time, regardless of bypass
+        """
         messages = [
-            teamserver_messages.ServerActivity(),
-            teamserver_messages.Preflight(context.activity),
-            teamserver_messages.Activity(context),
+            teamserver_messages.Preflight(
+                context.findings, context.activity.http_request
+            ),
         ]
 
         # Currently we do not report an observed route if the route signature is empty.
@@ -400,29 +414,7 @@ class BaseMiddleware(RoutesMixin):
         return messages
 
     def final_messages(self, context):
-        inventory_utils.append_db(context)
-
-        final_messages = [
-            context.activity,
-        ]
-
-        # Currently we do not report an observed route if the route signature is empty.
-        # As a team we've decided there isn't a meaningful default signature value
-        # we can provide to customers. If a route doesn't show up in Contrast UI,
-        # it may be due to its missing signature. In this scenario, we will have to work
-        # with the customer directly to understand why the signature was not created.
-        if self.settings.is_assess_enabled() and context.observed_route.signature:
-            final_messages.append(context.observed_route)
-
-        if self.first_request and self.settings.is_inventory_enabled():
-            # ApplicationUpdate message only sent at first request once we have routes
-            final_messages.append(
-                service_client.build_update_message(
-                    self.routes, framework_name=self.name
-                )
-            )
-
-        return final_messages
+        return [context.activity]
 
     def generate_security_exception_response(self):
         """
@@ -467,6 +459,12 @@ class BaseMiddleware(RoutesMixin):
         if not self.settings.is_protect_enabled():
             return
 
+        if (
+            self.settings.config.is_agent_lib_enabled
+            and self.settings.is_protect_enabled()
+        ):
+            input_analysis.get_input_analysis()
+
         with log_time_cm("protect prefilter"):
             context.speedracer_input_analysis = get_input_analysis()
             self.agent_prefilter()
@@ -495,7 +493,7 @@ class BaseMiddleware(RoutesMixin):
         """
         with log_time_cm("postfilter"):
             if self.settings.is_protect_enabled():
-                self.postfilter_defend()
+                self.postfilter_defend(context)
 
             if self.settings.is_assess_enabled():
                 with scope.contrast_scope():
@@ -553,13 +551,31 @@ class BaseMiddleware(RoutesMixin):
             return
 
         if self.settings.config.is_service_bypassed:
-            analyze_response_rules(context, self.reporting_client)
+            analyze_response_rules(context)
 
     @fail_quietly("Failed to run postfilter protect.")
-    def postfilter_defend(self):
+    def postfilter_defend(self, context):
         rules = self.settings.protect_rules
         logger.debug("PROTECT: Running Agent postfilter.")
+        if self.settings.config.is_agent_lib_enabled:
+            context.user_input_analysis = []
+            # Here we might have empty values if the rule is not enabled in settings
+            rules_list = [
+                (
+                    "sql-injection",
+                    self.settings.protect_rules.get(SqlInjection.RULE_NAME),
+                ),
+                (
+                    "cmd-injection",
+                    self.settings.protect_rules.get(CmdInjection.RULE_NAME),
+                ),
+            ]
 
+            input_analysis.get_input_analysis(rules_list)
+            if context.user_input_analysis:
+                for rule in context.user_input_analysis[0]:
+                    if rule.score >= 90:
+                        BaseRule().build_or_append_attack(rule)
         for rule in rules.values():
             if rule.is_postfilter():
                 rule.postfilter()
@@ -581,9 +597,9 @@ class BaseMiddleware(RoutesMixin):
         middleware exception handler. So this is really our first and our last
         opportunity to check for this particular edge case.
         """
-        for result in context.activity.results:
-            if result.response == AttackResult.BLOCKED:
-                msg = f"Rule {result.rule_id} threw a security exception"
+        for attack in context.attacks:
+            if attack.response == ProtectResponse.BLOCKED:
+                msg = f"Rule {attack.rule_id} threw a security exception"
                 raise SecurityException(None, message=msg)
 
     def log_start_request_analysis(self):
