@@ -19,8 +19,13 @@ class BaseResponseWrapper(object, metaclass=abc.ABCMeta):
         """
         Response headers as a dictionary-like object.
 
-        This object must support normalized lowercase lookup. For example:
+        This object **MUST** support normalized case-insensitive lookup.
+        For example, the following should all return the same value:
+
         my_response_wrapper.headers['content-length']
+        my_response_wrapper.headers['Content-Length']
+        my_response_wrapper.headers['CONTENT-LENGTH']
+        ... any other case variation
 
         In order to properly extract response headers for analysis, we currently expect
         this field to be a multidict that implements a method called `dict_of_lists()`.
@@ -51,8 +56,13 @@ class BaseAsyncResponseWrapper(object, metaclass=abc.ABCMeta):
         """
         Response headers as a dictionary-like object.
 
-        This object must support normalized lowercase lookup. For example:
+        This object **MUST** support normalized case-insensitive lookup.
+        For example, the following should all return the same value:
+
         my_response_wrapper.headers['content-length']
+        my_response_wrapper.headers['Content-Length']
+        my_response_wrapper.headers['CONTENT-LENGTH']
+        ... any other case variation
 
         In order to properly extract response headers for analysis, we currently expect
         this field to be a multidict that implements a method called `dict_of_lists()`.
