@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.agent.middlewares.route_coverage.coverage_utils import (
-    CoverageUtils,
-    DEFAULT_ROUTE_METHODS,
-)
 from contrast.api import Route
 from contrast.agent.middlewares.route_coverage.common import build_route
+from contrast.agent.middlewares.route_coverage.common import (
+    DEFAULT_ROUTE_METHODS,
+    get_normalized_uri,
+    build_key,
+)
 
 DEFAULT_ROUTE_METHODS = DEFAULT_ROUTE_METHODS + ("PUT", "PATCH", "DELETE")
 
@@ -24,10 +25,10 @@ def create_bottle_routes(app):
         route_id = str(id(view_func))
 
         for method_type in DEFAULT_ROUTE_METHODS:
-            key = CoverageUtils.build_key(route_id, method_type)
+            key = build_key(route_id, method_type)
             routes[key] = Route(
                 verb=method_type,
-                url=CoverageUtils.get_normalized_uri(str(rule.rule)),
+                url=get_normalized_uri(str(rule.rule)),
                 route=route,
             )
     return routes
