@@ -20,12 +20,14 @@ import re
 
 from contrast.api import Route
 
-
 DEFAULT_ROUTE_METHODS = ("GET", "POST")
 
 # 1 or more digits, then a group: either '/' or end of string
 DIGITS_ONLY_PATH_COMPONENT = r"/\d+(/|$)"
 
+# Retruns digits between '/' or end of string
+FIND_REQEUST_PARAMS = r"(?<=\/)\d+(?=\/|$)"
+
 
 def create_routes(app):
     """
@@ -65,6 +67,16 @@ def get_normalized_uri(path):
     return re.sub(DIGITS_ONLY_PATH_COMPONENT, r"/{n}\1", path)
 
 
+def get_url_parameters(path):
+    """
+    A best-effort to remove client-specific information from the path.
+
+    Example:
+    /user/123456/page/12 -> /user/{n}/page/{n}
+    """
+    return re.findall(FIND_REQEUST_PARAMS, path)
+
+
 def build_route(view_func_name, view_func):
     view_func_args = build_args_from_function(view_func)
     return view_func_name + view_func_args
@@ -77,7 +89,7 @@ def get_view_func_for_request(request, app):
     :param app: {Quart or Flask} app
     :return: function
     """
-    from werkzeug.exceptions import NotFound
+    from werkzeug.exceptions import NotFound, MethodNotAllowed
 
     adapter = app.url_map.bind("empty")
 
@@ -86,7 +98,7 @@ def get_view_func_for_request(request, app):
 
     try:
         match = adapter.match(request.path, method=request.method)
-    except NotFound:
+    except (NotFound, MethodNotAllowed):
         match = None
 
     func = None
