@@ -30,6 +30,8 @@ from contrast.agent.assess.policy.patches import (
     build_assess_deadzone,
     build_assess_property_fget,
     apply_cached_property,
+    build_assess_async_method,
+    build_assess_async_deadzone,
 )
 from contrast.agent.settings import Settings
 from contrast.agent.assess.policy.source_node import SourceNode
@@ -152,10 +154,11 @@ def apply_assess_patch(patch_site, patch_policy):
     elif static_method:
         new_method = staticmethod(build_assess_classmethod(old_method, patch_policy))
     elif iscoroutinefunction(old_method):
-        # we do the import here to prevent loading this file in pre-3.7!
-        from contrast.agent.assess.policy.async_patches import build_assess_async_method
-
-        new_method = build_assess_async_method(old_method, patch_policy)
+        new_method = (
+            build_assess_async_deadzone(old_method, patch_policy)
+            if patch_policy.is_deadzone
+            else build_assess_async_method(old_method, patch_policy)
+        )
     elif patch_policy.module in [
         "codecs",  # TODO: PYT-1975
         "falcon.util.uri",  # TODO: PYT-1976
