@@ -29,7 +29,7 @@ from contrast.agent.assess.rules.triggers import (
     SessionRewritingRule,
 )
 from contrast.utils.singleton import Singleton
-from contrast.utils.decorators import cached_property, fail_safely
+from contrast.utils.decorators import cached_property, fail_loudly
 
 from contrast.extern import structlog as logging
 
@@ -167,12 +167,12 @@ class Policy(Singleton):
 
             self.providers[instance.name] = instance
 
-    @fail_safely("Failed to read policy json file")
+    @fail_loudly("Failed to read policy json file")
     def _get_json_data(self):
         with open(self.POLICY_JSON_PATH) as json_file:
             return json.load(json_file)
 
-    @fail_safely("Failed to add node to policy")
+    @fail_loudly("Failed to add node to policy")
     def add_source_node(self, node):
         node.validate()
         self.sources.append(node)
