@@ -107,7 +107,7 @@ def reverse_patches_by_owner(owner):
 
     :param owner: module or class that owns the attribute being reverse patched
     """
-    if not id(owner) in module.patches_by_owner:
+    if id(owner) not in module.patches_by_owner:
         return
 
     for name in list(module.patches_by_owner[id(owner)]):
