@@ -4,8 +4,7 @@
 from contrast.agent.policy import constants
 from contrast.agent.assess.assess_exceptions import ContrastAssessException
 from contrast.agent.policy.constants import ALL_ARGS, OBJECT, RETURN
-from contrast.api.dtm_pb2 import TraceEvent
-
+from contrast.api.trace_event import TraceEvent
 
 UNDERSCORE = "_"
 COMMA = ","
@@ -254,15 +253,15 @@ class PolicyNode(object):
         :return: self.event_action
         """
         if not self.sources:
-            event_action = TraceEvent.Action.Value(constants.CREATION_TYPE)
+            event_action = TraceEvent.Action[constants.CREATION_TYPE]
         elif not self.targets:
-            event_action = TraceEvent.Action.Value(constants.TRIGGER_TYPE)
+            event_action = TraceEvent.Action[constants.TRIGGER_TYPE]
         else:
             source = self._type_to_action(self.sources)
             target = self._type_to_action(self.targets)
             str_action = source + constants.TO_MARKER + target
 
-            event_action = TraceEvent.Action.Value(str_action)
+            event_action = TraceEvent.Action[str_action]
 
         return event_action
 
