@@ -6,11 +6,15 @@ import re
 
 
 import contrast
+from contrast.agent import agent_lib
+from contrast.agent.agent_lib import get_index_of_chained_cmd
+from contrast.agent.agent_lib import does_command_contain_dangerous_path
 from contrast.agent.protect.rule.base_rule import BaseRule
 from contrast.agent.protect.rule.cmd_injection.cmd_injection_rep_mixin import (
     CommandInjectionREPMixin,
 )
-from contrast.api.dtm_pb2 import HttpRequest, UserInput
+from contrast.api.dtm_pb2 import HttpRequest
+from contrast.api.user_input import UserInput
 from contrast.utils.exceptions.security_exception import SecurityException
 from contrast.utils.string_utils import index_of_any
 
@@ -21,6 +25,7 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
     """
 
     RULE_NAME = "cmd-injection"
+    BITMASK_VALUE = agent_lib.CONSTANTS.RuleType.get(RULE_NAME)
 
     BIN_SH_C = "/bin/sh-c"
 
@@ -52,19 +57,37 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
 
         return current_pid != original_pid
 
+    def is_chained_command(self, command):
+        """
+        A command is chained if it is piped, backgrounded, or appended
+        """
+        if self.settings.config.is_agent_lib_enabled:
+            return get_index_of_chained_cmd(command) != -1
+
+        return index_of_any(command, self.CHAIN) != -1
+
+    def does_contain_dangerous_path(self, command):
+        if self.settings.config.is_agent_lib_enabled:
+            return does_command_contain_dangerous_path(command) == 1
+
+        return False
+
     def find_probable_attack(self, command_string, evaluations_for_rule, **kwargs):
         """
-        Search through the attack string for a command that may of been executed
+        Search through the attack string for a command that may have been executed
         """
-
-        if not self.is_chained_command(command_string):
+        if not self.is_chained_command(
+            command_string
+        ) and not self.does_contain_dangerous_path(command_string):
             return None
 
         attack = None
         most_likely = None
 
         for evaluation in evaluations_for_rule:
-            if not self.is_chained_command(evaluation.value):
+            if not self.is_chained_command(
+                evaluation.value
+            ) and not self.does_contain_dangerous_path(evaluation.value):
                 continue
 
             most_likely = evaluation
@@ -81,29 +104,23 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
 
         return attack
 
-    def is_chained_command(self, command):
-        """
-        A command is chained if it is piped, backgrounded, or appended
-        """
-        return index_of_any(command, self.CHAIN) != -1
-
     def build_sample(self, evaluation, command, **kwargs):
         sample = self.build_base_sample(evaluation)
 
         if command is not None:
-            sample.cmdi.command = command
+            sample.details["command"] = command
 
         if self.START_IDX in kwargs or self.END_IDX in kwargs:
-            sample.cmdi.start_idx = kwargs.get(self.START_IDX, 0)
-            sample.cmdi.end_idx = kwargs.get(self.END_IDX, 0)
+            sample.details["startIndex"] = kwargs.get(self.START_IDX, 0)
+            sample.details["endIndex"] = kwargs.get(self.END_IDX, 0)
         elif command is not None:
             search_value = evaluation.value
 
             match = re.search(search_value, command, re.IGNORECASE)
 
             if match:
-                sample.cmdi.start_idx = match.start()
-                sample.cmdi.end_idx = match.end()
+                sample.details["startIndex"] = match.start()
+                sample.details["endIndex"] = match.end()
 
         return sample
 
@@ -140,6 +157,7 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
             self.detect_command_backdoor(context, original_command)
 
         evaluations_for_rule = self.evaluations_for_rule()
+
         if not evaluations_for_rule:
             return
 
@@ -147,6 +165,10 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
             evaluation = evaluations_for_rule[0]
             self.detect_command_chaining(original_command, evaluation)
 
+        if self.settings.config.is_agent_lib_enabled:
+            evaluation = evaluations_for_rule[0]
+            self.detect_dangerous_path(original_command, evaluation)
+
         super().infilter(match_string, **kwargs)
 
     def detect_command_backdoor(self, context, command):
@@ -168,7 +190,10 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
         If we detected an attack inbound but we didn't see it in the command
         we still might want to fuzzy match on chained attacks.
         """
-        index = self.get_first_command_chain_index(command)
+        if self.settings.config.is_agent_lib_enabled:
+            index = get_index_of_chained_cmd(command)
+        else:
+            index = self.get_first_command_chain_index(command)
 
         if index != -1:
             self.report_chained_injection(evaluation, command, index)
@@ -176,6 +201,15 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
             if self.is_blocked():
                 raise SecurityException(self, "Command chaining detected")
 
+    def detect_dangerous_path(self, command, evaluation):
+        is_dangerous_path_detected = does_command_contain_dangerous_path(command)
+
+        if is_dangerous_path_detected == 1:
+            self.report_dangerous_path(evaluation, command)
+
+            if self.is_blocked():
+                raise SecurityException(self, "Dangerous path detected")
+
     def find_matching_parameter(self, context, command):
         request = context.request
 
@@ -222,13 +256,13 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
 
         attack = self.build_base_attack()
 
-        attack.samples.extend([sample])
+        attack.add_sample(sample)
 
-        attack.response = self.response_from_mode(self.mode)
+        attack.set_response(self.response_from_mode(self.mode))
 
         self.log_rule_matched(evaluation, attack.response, parameter_value)
 
-        self._append_to_activity(attack)
+        self._append_to_context(attack)
 
     def report_chained_injection(self, evaluation, command, offset):
         start_idx = offset
@@ -240,30 +274,48 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
             command, evaluation, attack, start_idx=start_idx, end_idx=end_idx
         )
 
-        self._append_to_activity(result)
+        self._append_to_context(result)
+
+    def report_dangerous_path(self, evaluation, command):
+        attack = self.build_or_append_attack(evaluation, candidate_string=command)
+
+        result = self.build_attack_with_match(command, evaluation, attack)
+
+        self._append_to_context(result)
 
     def create_backdoor_command_sample(
         self, evaluation, command, parameter_key, parameter_value
     ):
+
         sample = self.build_base_sample(evaluation)
-
-        sample.user_input.key = parameter_key
-        sample.user_input.value = parameter_value
-        sample.user_input.input_type = UserInput.PARAMETER_VALUE
-        sample.user_input.document_type = HttpRequest.NORMAL
-        sample.user_input.matcher_ids.extend(
-            [self.REP_DETECT_PARAMETER_COMMAND_BACKDOORS_ID]
+        user_input = UserInput(
+            input_type=UserInput.PARAMETER_VALUE,
+            key=parameter_key,
+            value=parameter_value,
+            matcher_ids=[self.REP_DETECT_PARAMETER_COMMAND_BACKDOORS_ID],
+            document_type=HttpRequest.NORMAL,
         )
+        sample.set_user_input(user_input)
 
-        sample.cmdi.command = command
-        sample.cmdi.start_idx = 0
-        sample.cmdi.end_idx = 0
+        start_index = 0
+        end_index = 0
+        boundary_overrun_idx = 0
+        input_boundary_idx = 0
+
+        if self.settings.config.is_agent_lib_enabled:
+            agent_lib_evaluation = agent_lib.check_cmd_injection_query(
+                0, len(user_input.value), user_input.value
+            )
+            if bool(agent_lib_evaluation):
+                start_index = agent_lib_evaluation.start_index
+                end_index = agent_lib_evaluation.end_index
+                boundary_overrun_idx = agent_lib_evaluation.boundary_overrun_index
+                input_boundary_idx = agent_lib_evaluation.input_boundary_index
+
+        sample.details["command"] = command
+        sample.details["startIndex"] = start_index
+        sample.details["endIndex"] = end_index
+        sample.details["boundary_overrun_idx"] = boundary_overrun_idx
+        sample.details["input_boundary_idx"] = input_boundary_idx
 
         return sample
-
-    def sample_dtm_to_json(self, sample):
-        return {
-            "command": sample.cmdi.command,
-            "startIndex": sample.cmdi.start_idx,
-            "endIndex": sample.cmdi.end_idx,
-        }
