@@ -4,7 +4,8 @@
 from contrast.agent.protect.rule.base_rule import BaseRule
 from contrast.agent.protect.rule.deserialization.pickle_searcher import PickleSearcher
 from contrast.agent.protect.rule.deserialization.yaml_searcher import YAMLSearcher
-from contrast.api.dtm_pb2 import AttackResult, UserInput
+from contrast.api.user_input import UserInput
+from contrast.api.attack import ProtectResponse
 from contrast.api.settings_pb2 import InputAnalysisResult
 from contrast.utils.exceptions.security_exception import SecurityException
 from contrast.utils.string_utils import ends_with_any
@@ -132,9 +133,9 @@ class Deserialization(BaseRule):
         evaluation = self.build_evaluation(value)
         attack = self.build_attack_with_match(value, evaluation, **kwargs)
 
-        attack.response = AttackResult.BLOCKED
+        attack.set_response(ProtectResponse.BLOCKED)
 
-        self._append_to_activity(attack)
+        self._append_to_context(attack)
 
         raise SecurityException(
             self,
@@ -166,10 +167,10 @@ class Deserialization(BaseRule):
     def build_sample(self, evaluation, input_value, **kwargs):
         sample = self.build_base_sample(evaluation)
 
-        sample.untrusted_deserialization.command = False
+        sample.details["command"] = False
 
         if "deserializer" in kwargs:
-            sample.untrusted_deserialization.deserializer = kwargs["deserializer"]
+            sample.details["deserializer"] = kwargs["deserializer"]
 
         return sample
 
@@ -207,9 +208,3 @@ class Deserialization(BaseRule):
         return dict(
             deserializer=patch_policy.method_name, stack_elements=stack_elements
         )
-
-    def sample_dtm_to_json(self, sample):
-        return {
-            "command": sample.untrusted_deserialization.command,
-            "deserializer": sample.untrusted_deserialization.deserializer,
-        }
