@@ -2,6 +2,7 @@
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import contrast
+from contrast.agent import agent_lib
 from contrast.agent.protect.rule.base_rule import BaseRule, UserInput
 
 from contrast.extern import structlog as logging
@@ -11,7 +12,8 @@ logger = logging.getLogger("contrast")
 
 class MethodTampering(BaseRule):
     RULE_NAME = "method-tampering"
-    USER_INPUT_KEY = UserInput.InputType.Name(UserInput.METHOD)
+    BITMASK_VALUE = agent_lib.CONSTANTS.RuleType.get(RULE_NAME)
+    USER_INPUT_KEY = UserInput.type_to_str(UserInput.METHOD)
 
     def postfilter(self):
         """
@@ -44,28 +46,22 @@ class MethodTampering(BaseRule):
                     method=evaluation.value,
                     response_code=response_code,
                 )
-            self._append_to_activity(attack)
+            self._append_to_context(attack)
 
     def build_sample(self, evaluation, candidate_string, **kwargs):
         sample = self.build_base_sample(None)
 
         method = kwargs.get("method", "")
 
-        sample.method_tampering.method = method
-        sample.method_tampering.response_code = kwargs.get("response_code", -1)
-        sample.user_input.CopyFrom(self.build_user_input(method))
+        sample.details["method"] = method
+        sample.details["responseCode"] = kwargs.get("response_code", -1)
+        sample.set_user_input(self.build_user_input(method))
 
         return sample
 
     def build_user_input(self, method):
-        ui = UserInput()
-        ui.key = self.USER_INPUT_KEY
-        ui.input_type = UserInput.METHOD
-        ui.value = method
-        return ui
-
-    def sample_dtm_to_json(self, sample):
-        return {
-            "method": sample.method_tampering.method,
-            "responseCode": sample.method_tampering.response_code,
-        }
+        return UserInput(
+            input_type=UserInput.METHOD,
+            key=self.USER_INPUT_KEY,
+            value=method,
+        )
