@@ -2,7 +2,7 @@
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.protect.rule.base_rule import BaseRule
-from contrast.api.settings_pb2 import ProtectionRule
+from contrast.agent.protect.rule import ProtectionRule
 
 
 class MalformedHeader(BaseRule):
