@@ -2,6 +2,8 @@
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import json
+
+from contrast.agent import agent_lib
 from contrast.agent.protect.rule.nosql_injection.mongo_nosql_scanner import (
     MongoNoSqlScanner,
 )
@@ -15,25 +17,7 @@ class NoSqlInjection(SqlInjection):
     """
 
     RULE_NAME = "nosql-injection"
-
-    def build_sample(self, evaluation, query, **kwargs):
-        sample = self.build_base_sample(evaluation)
-        if query is not None:
-            sample.no_sqli.query = query
-
-        if "start_idx" in kwargs:
-            sample.no_sqli.start_idx = int(kwargs["start_idx"])
-
-        if "end_idx" in kwargs:
-            sample.no_sqli.end_idx = int(kwargs["end_idx"])
-
-        if "boundary_overrun_idx" in kwargs:
-            sample.no_sqli.boundary_overrun_idx = int(kwargs["boundary_overrun_idx"])
-
-        if "input_boundary_idx" in kwargs:
-            sample.no_sqli.input_boundary_idx = int(kwargs["input_boundary_idx"])
-
-        return sample
+    BITMASK_VALUE = agent_lib.CONSTANTS.RuleType.get(RULE_NAME + "-mongo")
 
     def get_database_scanner(self, database):
         return MongoNoSqlScanner()
@@ -51,15 +35,6 @@ class NoSqlInjection(SqlInjection):
 
         return super().convert_input(user_input)
 
-    def sample_dtm_to_json(self, sample):
-        return {
-            "start": sample.no_sqli.start_idx,
-            "end": sample.no_sqli.end_idx,
-            "boundaryOverrunIndex": sample.no_sqli.boundary_overrun_idx,
-            "inputBoundaryIndex": sample.no_sqli.input_boundary_idx,
-            "query": sample.no_sqli.query,
-        }
-
 
 @fail_quietly("Failed to convert nosql obj input to str", return_value="")
 def obj_to_str(obj):
