@@ -2,20 +2,24 @@
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast import AGENT_CURR_WORKING_DIR
+from contrast.agent import agent_lib
 from contrast.agent.protect.mixins.path_traversal_sink_features import (
     PathTraversalSinkFeatures,
 )
 from contrast.agent.protect.rule.base_rule import BaseRule, INFILTER
+from collections.abc import Iterable
 
 from contrast.utils.decorators import fail_quietly
 
 PARENT_CHECK = ".."
 SLASH = "/"
 SAFE_PATHS = ["tmp", "public", "docs", "static", "template", "templates"]
+WRITE_OPTIONS = ["w", "a"]
 
 
 class PathTraversal(BaseRule, PathTraversalSinkFeatures):
     RULE_NAME = "path-traversal"
+    BITMASK_VALUE = agent_lib.CONSTANTS.RuleType.get(RULE_NAME)
 
     def find_attack(self, candidate_string=None, analysis_stage=None, **kwargs):
         """
@@ -32,7 +36,7 @@ class PathTraversal(BaseRule, PathTraversalSinkFeatures):
     def build_sample(self, evaluation, path, **kwargs):
         sample = self.build_base_sample(evaluation)
         if path is not None:
-            sample.path_traversal.path = path
+            sample.details["path"] = path
         return sample
 
     @fail_quietly(
@@ -49,15 +53,30 @@ class PathTraversal(BaseRule, PathTraversalSinkFeatures):
     def infilter_kwargs(self, user_input, patch_policy):
         return dict(method=patch_policy.method_name)
 
-    def sample_dtm_to_json(self, sample):
-        return {"path": sample.path_traversal.path}
-
 
 def possible_write(args, kwargs):
-    if "w" in kwargs.get("mode", ""):
-        return True
+    return _possible_write_kwargs(kwargs) or _possible_write_args(args)
 
-    return len(args) > 1 and args[1] is not None and "w" in args[1]
+
+def _possible_write_kwargs(kwargs):
+    mode = kwargs.get("mode", "")
+
+    if not isinstance(mode, (str, bytes)):
+        return False
+
+    return mode and any([x in mode for x in WRITE_OPTIONS])
+
+
+def _possible_write_args(args):
+    if not isinstance(args, Iterable):
+        return False
+
+    return (
+        len(args) > 1
+        and args[1] is not None
+        and isinstance(args[1], Iterable)
+        and any([x in args[1] for x in WRITE_OPTIONS])
+    )
 
 
 def actionable_path(path):
