@@ -14,6 +14,7 @@ from contrast.agent.protect.rule.ssrf_rule import Ssrf
 from contrast.agent.protect.rule.unsafe_file_upload_rule import UnsafeFileUpload
 from contrast.agent.protect.rule.xss_rule import Xss
 from contrast.agent.protect.rule.xxe_rule import Xxe
+from contrast.agent.protect.rule.bot_blocker_rule import BotBlocker
 
 
 def build_protect_rules():
@@ -26,6 +27,7 @@ def build_protect_rules():
     rules = OrderedDict(
         {
             UnsafeFileUpload.RULE_NAME: UnsafeFileUpload(),
+            BotBlocker.RULE_NAME: UnsafeFileUpload(),
             CmdInjection.RULE_NAME: CmdInjection(),
             Deserialization.RULE_NAME: Deserialization(),
             # Turned off until TS can handle rule information
