@@ -22,8 +22,5 @@ class Ssrf(BaseRule):
     def build_sample(self, evaluation, url, **kwargs):
         sample = self.build_base_sample(evaluation)
         if url is not None:
-            sample.ssrf.url = url
+            sample.details["url"] = url
         return sample
-
-    def sample_dtm_to_json(self, sample):
-        return {"url": sample.ssrf.url}
