@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
+from contrast.agent import agent_lib
 from contrast.agent.protect.rule.base_rule import BaseRule
 
 
@@ -11,3 +12,4 @@ class UnsafeFileUpload(BaseRule):
     """
 
     RULE_NAME = "unsafe-file-upload"
+    BITMASK_VALUE = agent_lib.CONSTANTS.RuleType.get(RULE_NAME)
