@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
+from contrast.agent import agent_lib
 from contrast.agent.protect.rule.base_rule import BaseRule
-from contrast.api.settings_pb2 import ProtectionRule
+from contrast.agent.protect.rule import ProtectionRule
 
 
 class Xss(BaseRule):
@@ -12,6 +13,7 @@ class Xss(BaseRule):
     """
 
     RULE_NAME = "reflected-xss"
+    BITMASK_VALUE = agent_lib.CONSTANTS.RuleType.get(RULE_NAME)
 
     @property
     def mode(self):
@@ -25,16 +27,3 @@ class Xss(BaseRule):
             if mode in [ProtectionRule.NO_ACTION, ProtectionRule.MONITOR]
             else ProtectionRule.BLOCK_AT_PERIMETER
         )
-
-    def sample_dtm_to_json(self, sample):
-        return {
-            "input": sample.xss.input,
-            "matches": [
-                {
-                    "evidenceStart": match.evidence_start_ms,
-                    "evidence": match.evidence,
-                    "offset": match.offset,
-                }
-                for match in sample.xss.matches
-            ],
-        }
