@@ -5,7 +5,8 @@ import re
 
 from contrast.agent.protect.rule.base_rule import BaseRule
 from contrast.agent.protect.rule.xxe.entity_wrapper import EntityWrapper
-from contrast.api.dtm_pb2 import RaspRuleSample, UserInput, XxeMatch, XxeWrapper
+from contrast.api.user_input import UserInput
+from contrast.api.sample import Sample
 from contrast.utils.stack_trace_utils import build_and_clean_stack
 
 
@@ -60,57 +61,36 @@ class Xxe(BaseRule):
         return attack
 
     def _build_match(self, match_string, end_idx):
-        match = XxeMatch()
-        match.end_idx = end_idx
-        match.start_idx = end_idx - len(match_string)
-        return match
+        return {"start": end_idx - len(match_string), "end": end_idx}
 
-    def _build_wrapper(self, entity_wrapper):
-        wrapper = XxeWrapper()
-        wrapper.system_id = entity_wrapper.system_id
-        wrapper.public_id = entity_wrapper.public_id
-        return wrapper
+    def _build_wrapper(self, entity):
+        return {"systemId": entity.system_id, "publicId": entity.public_id}
 
     def build_sample(self, evaluation, url, **kwargs):
         sample = self.build_base_sample(evaluation)
         declared_entities = kwargs["declared_entities"]
         if declared_entities:
-            sample.xxe.declared_entities.extend(declared_entities)
+            sample.details["declaredEntities"] = declared_entities
 
         entities_resolved = kwargs["entities_resolved"]
         if entities_resolved:
-            sample.xxe.entities_resolved.extend(entities_resolved)
+            sample.details["entitiesResolved"] = entities_resolved
 
-        sample.xxe.xml = self.prolog_xml
+        sample.details["xml"] = self.prolog_xml
         return sample
 
-    def build_base_sample(self, evaluation, prebuilt_stack=None):
-        sample = RaspRuleSample()
-        sample.stack_trace_elements.extend(build_and_clean_stack())
-
-        sample.user_input.CopyFrom(self.build_user_input(evaluation))
-
+    def build_base_sample(self, evaluation, **args):
+        sample = Sample()
+        sample.set_user_input(self.build_user_input(evaluation))
+        sample.set_stack(build_and_clean_stack())
         return sample
 
-    def build_user_input(self, evaluation):
-        ui = UserInput()
-        ui.key = self.INPUT_NAME
-        ui.input_type = UserInput.UNKNOWN
-        ui.value = self.prolog_xml
-        return ui
+    def build_user_input(self, _):
+        return UserInput(
+            input_type=UserInput.UNKNOWN,
+            key=self.INPUT_NAME,
+            value=self.prolog_xml,
+        )
 
     def infilter_kwargs(self, user_input, patch_policy):
         return dict(framework=patch_policy.method_name)
-
-    def sample_dtm_to_json(self, sample):
-        return {
-            "xml": sample.xxe.xml,
-            "declaredEntities": [
-                {"start": entity.start_idx, "end": entity.end_idx}
-                for entity in sample.xxe.declared_entities
-            ],
-            "entitiesResolved": [
-                {"systemId": entity.system_id, "publicId": entity.public_id}
-                for entity in sample.xxe.entities_resolved
-            ],
-        }
