@@ -5,7 +5,8 @@ from contrast.agent import scope
 
 from contrast.agent.request import Request
 from contrast.agent.settings import Settings
-from contrast.api.dtm_pb2 import Activity, ObservedRoute
+from contrast.api.dtm_pb2 import Activity
+from contrast.api.route_coverage import Route
 
 from contrast.extern import structlog as logging
 from contrast.utils.digest_utils import Digest
@@ -25,16 +26,30 @@ class RequestContext(object):
         self.activity = Activity()
         self.activity.http_request.CopyFrom(dtm)
 
+        # This contains input exclusions that should always apply regardless of rule on this request
+        self.input_exclusions = None
+
+        # This contains exclusions that only apply at trigger time based on the source event
+        self.input_exclusions_trigger_time = None
+
+        self.excluded_assess_rules = []
+        self.excluded_protect_rules = []
+
         # For protect: store attacks made during a request to report at the end
         self.attacks = []
 
+        # For assess: store findings made during a request to report at the end
+        self.findings = []
+
         self.speedracer_input_analysis = None
+        self.user_input_analysis = []
+        self.response = None
         self.do_not_track = False
 
-        # to be populated with a RouteCoverage dtm instance
+        # to be populated with a Route instance
         self.current_route = None
 
-        self.observed_route = ObservedRoute()
+        self.observed_route = Route("", "", "")
         self.database_info = []
         self.source_count = 0
         self.propagation_count = 0
@@ -63,8 +78,7 @@ class RequestContext(object):
         hasher.update(self.request.content_length)
         return hasher.finish()
 
-    @property
-    def stop_source_creation(self):
+    def stop_source_creation(self, context, source_type, source_name):
         """
         Compare `source_count` to `max_context_source_events` config option
         :return: true if source_count within this request is equal to or
@@ -73,6 +87,11 @@ class RequestContext(object):
         if self.max_sources_logged:
             return True
 
+        if context.input_exclusions and Settings().exclusions.evaluate_input_exclusions(
+            context, source_type, source_name
+        ):
+            return True
+
         threshold_reached = self.source_count >= Settings().max_sources
         if threshold_reached:
             logger.warning(
@@ -148,16 +167,6 @@ class RequestContext(object):
             response.body or ""
         )
 
-    def get_xss_findings(self):
-        """
-        Return a list of Finding obj of rule_id reflected-xss, if any exist in Activity
-        """
-        return [
-            finding
-            for finding in self.activity.findings
-            if finding.rule_id == "reflected-xss"
-        ]
-
     def truncate_request_body(self):
         # Request body is truncated to not overwhelm ContrastUI.
         raw_request_body = self.activity.http_request.request_body_binary
