@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from copy import deepcopy
 import importlib.abc
 import importlib.machinery
 import importlib.util
@@ -24,6 +23,26 @@ from contrast.extern import structlog as logging
 logger = logging.getLogger("contrast")
 
 
+def _load_module(source, module: types.ModuleType, filename):
+    # For now this function should only be used to execute the original source code
+    success = True
+
+    if source is not None:
+        try:
+            code = compile(source, filename, "exec", dont_inherit=True)
+
+            exec(code, module.__dict__)
+        except Exception as ex:
+            logger.debug(
+                "WARNING: Failed to execute python module %s",
+                filename,
+                exc_info=ex,
+            )
+            success = False
+
+    return success
+
+
 class ContrastMetaPathFinder(importlib.abc.MetaPathFinder):
     @fail_loudly("Unexpected error in find_spec - will not rewrite this module")
     def find_spec(self, fullname, path, target=None):
@@ -50,11 +69,12 @@ class ContrastMetaPathFinder(importlib.abc.MetaPathFinder):
             )
             return None
 
-        if not default_spec.origin.endswith(".py"):
+        default_spec_origin = getattr(default_spec, "origin", "") or ""
+        if not default_spec_origin.endswith(".py"):
             logger.debug(
                 "Will not rewrite non *.py file - fullname=<%s>, path=<%s>",
                 fullname,
-                default_spec.origin,
+                default_spec_origin,
             )
             return None
 
@@ -85,12 +105,24 @@ class ContrastRewriteLoader(importlib.abc.Loader):
         the need for import rewriting entirely
         """
         with scope.contrast_scope():
+            original_source_code = None
             filename = module.__spec__.origin
-            with open(filename) as f:
-                source = f.read()
 
-            tree = ast.parse(source)
-            original_tree = deepcopy(tree)
+            # May be None in some cases such as for namespace packages
+            if filename is None:
+                return
+
+            try:
+                with open(filename) as f:
+                    original_source_code = f.read()
+
+                tree = ast.parse(original_source_code)
+            except Exception as ex:
+                _load_module(original_source_code, module, filename)
+
+                logger.debug("WARNING: failed to rewrite %s", filename, exc_info=ex)
+
+                return
 
             if "contrast__add" not in module.__dict__:
                 try:
@@ -98,22 +130,18 @@ class ContrastRewriteLoader(importlib.abc.Loader):
                     module.__dict__["contrast__append"] = contrast__append
                     ConcatRewriter().visit(tree)
                     ast.fix_missing_locations(tree)
-                except Exception:
-                    logger.debug("WARNING: failed to rewrite %s", filename)
+                except Exception as ex:
+                    logger.debug("WARNING: failed to rewrite %s", filename, exc_info=ex)
             else:
                 logger.debug(
                     "WARNING: contrast__add is already defined in %s; will not rewrite",
                     filename,
                 )
 
-            try:
-                co = compile(tree, filename, "exec", dont_inherit=True)
-            except (ValueError, TypeError):
-                # TODO: PYT-2086 consider safety benefit of keeping
-                # except Exception versus having to keep original_tree in memory
-                co = compile(original_tree, filename, "exec", dont_inherit=True)
+            if not _load_module(tree, module, filename):
+                logger.debug("WARNING: failed to rewrite %s", filename)
 
-            exec(co, module.__dict__)
+                _load_module(original_source_code, module, filename)
 
 
 class ConcatRewriter(ast.NodeTransformer):
@@ -158,12 +186,12 @@ class ConcatRewriter(ast.NodeTransformer):
         if isinstance(node.target, ast.Name):
             target_id = node.target.id
         elif isinstance(node.target, ast.Attribute):
-            # TODO: PYT-2086 this needs more work?
-            target_id = node.target.value.id
+            target_id = node.target.value
         # TODO: PYT-2086 add else stmt
 
+        # TODO: PYT-2086 This will never be satisfied by a node, so target id must be a string.
+        #   To support the ast.Attribute type, we need to determine how to better handle Node passing.
         if not isinstance(target_id, str) or not isinstance(value_id, str):
-            # TODO: PYT-2086
             return node
 
         call_contrast_append_node = ast.Assign(
@@ -171,6 +199,7 @@ class ConcatRewriter(ast.NodeTransformer):
             value=ast.Call(
                 func=ast.Name(id="contrast__append", ctx=ast.Load()),
                 args=[
+                    # TODO: PYT-2086 Determine why we can't pass target & value nodes here
                     ast.Name(id=target_id, ctx=ast.Load()),
                     ast.Name(id=value_id, ctx=ast.Load()),
                 ],
@@ -222,6 +251,12 @@ def register():
     Rewriter should only run in py3.10 and only in environments in which our default
     patching mechanism does not work.
     """
+    settings = Settings()
+
+    if not settings.is_rewriter_enabled:
+        logger.debug("Rewriter disabled exiting setup")
+        return
+
     if sys.version_info[:2] != (3, 10):
         # Don't register rewriter in a non py3.10 environment
         return
@@ -232,7 +267,6 @@ def register():
 
     sys.meta_path.insert(0, ContrastMetaPathFinder())
 
-    settings = Settings()
     settings.rewriter_enabled = True
 
     logger.debug("enabled AST rewriter")
