@@ -13,10 +13,8 @@ from contrast.api.dtm_pb2 import (
     Activity,
     AgentStartup,
     ApplicationCreate,
-    ApplicationUpdate,
     HttpRequest,
     Message,
-    ObservedRoute,
     Poll,
 )
 from contrast.api.settings_pb2 import AgentSettings
@@ -95,7 +93,7 @@ class _ServiceState(Singleton):
             self.service_config.address,
         )
 
-        path = settings.config.get("agent.service.logger.path")
+        path = settings.config.get("agent.service.logger.path", "contrast_service.log")
 
         if not ServiceUtil(path).start_bundled_service():
             logger.error("Contrast Service did not start")
@@ -353,15 +351,9 @@ class _ServiceState(Singleton):
         if isinstance(agent_message, ApplicationCreate):
             message.application_create.CopyFrom(agent_message)
 
-        if isinstance(agent_message, ApplicationUpdate):
-            message.application_update.CopyFrom(agent_message)
-
         if isinstance(agent_message, HttpRequest):
             message.prefilter.CopyFrom(agent_message)
 
-        if isinstance(agent_message, ObservedRoute):
-            message.observed_route.CopyFrom(agent_message)
-
         if isinstance(agent_message, Poll):
             message.poll.CopyFrom(agent_message)
 
@@ -373,7 +365,6 @@ class _ServiceState(Singleton):
 
         contrast.api.dtm.AgentStartup agent_startup = 11;
         contrast.api.dtm.ApplicationCreate application_create = 12;
-        contrast.api.dtm.ApplicationUpdate application_update = 13;
         contrast.api.dtm.Activity activity = 14;
         contrast.api.dtm.Poll
         """
@@ -439,29 +430,6 @@ def is_connected():
     return _ServiceState().connection_status.connected
 
 
-def build_update_message(routes, framework_name):
-    """
-    Create an ApplicationUpdate message with framework information and routes.
-
-    :param routes: Dict of api.Route, will be empty if in Protect mode
-    :return: ApplicationUpdate instance
-    """
-    settings = Settings(framework_name=framework_name)
-
-    update_message = ApplicationUpdate()
-
-    update_message.platform.major = settings.framework.version.major
-    update_message.platform.minor = settings.framework.version.minor
-    update_message.platform.build = settings.framework.version.patch
-
-    # Route coverage is an assess feature. Routes will be empty
-    # so the update_message will have no routes.
-    for route in routes.values():
-        update_message.routes.extend([route.to_dtm()])
-
-    return update_message
-
-
 def send_messages_get_responses(messages):
     """Send messages to service and return responses"""
     service_state = _ServiceState()
