@@ -7,23 +7,23 @@ from urllib.parse import urlparse
 from contrast import AGENT_CURR_WORKING_DIR
 
 from contrast.agent.framework import Framework, Server
-from contrast.agent.heartbeat import Heartbeat
 from contrast.agent.protect.mixins.REP_settings import SettingsREPMixin
 from contrast.agent.reaction_processor import ReactionProcessor
+from contrast.agent.protect.rule import ProtectionRule
 from contrast.api.settings_pb2 import (
     AccumulatorSettings as DtmAccumulatorSettings,
     AgentSettings as DtmAgentSettings,
     ApplicationSettings as DtmApplicationSettings,
     ServerFeatures as DtmServerFeatures,
-    ProtectionRule as DtmProtectionRule,
 )
 from contrast.configuration import AgentConfig, SamplingLockConfig
-from contrast.utils.decorators import cached_property, fail_loudly
+from contrast.utils.decorators import cached_property
 from contrast.utils.loggers.logger import reset_agent_logger
 from contrast.utils.singleton import Singleton
 from contrast.utils.string_utils import truncate
 from contrast.utils.timer import now_ms
 from contrast.extern import structlog as logging
+from contrast.agent.exclusions import Exclusions, ExclusionMapper
 
 logger = logging.getLogger("contrast")
 
@@ -84,6 +84,16 @@ class ApplicationSettings:
             .get("session_id")
         )
 
+    @cached_property
+    def sensitive_data_masking_policy(self):
+        return self._raw_settings.get("settings", {}).get(
+            "sensitive_data_masking_policy"
+        )
+
+    @cached_property
+    def exclusions(self):
+        return self._raw_settings.get("settings", {}).get("exceptions")
+
     # note: there are many more fields on the ApplicationSettings that we currently do
     # not use
 
@@ -101,13 +111,13 @@ class ProtectRule:
         raw_mode = self._raw_rule.get("mode", "OFF")
         raw_block_at_entry = self._raw_rule.get("blockAtEntry", False)
         return {
-            "MONITORING": DtmProtectionRule.MONITOR,
+            "MONITORING": ProtectionRule.MONITOR,
             "BLOCKING": (
-                DtmProtectionRule.BLOCK_AT_PERIMETER
+                ProtectionRule.BLOCK_AT_PERIMETER
                 if raw_block_at_entry
-                else DtmProtectionRule.BLOCK
+                else ProtectionRule.BLOCK
             ),
-            "OFF": DtmProtectionRule.NO_ACTION,
+            "OFF": ProtectionRule.NO_ACTION,
         }[raw_mode]
 
 
@@ -120,10 +130,12 @@ class Settings(Singleton, SettingsREPMixin):
         """
         self.config = None
         self.config_features = {}
+        self.exclusions = None
         self.last_update_service = None
         self.last_server_update_time_ms = 0
         self.last_app_update_time_ms = 0
         self.heartbeat = None
+        self.server_settings_poll = None
         self.framework = Framework(framework_name)
         self.server = Server()
         self.sys_module_count = 0
@@ -265,6 +277,10 @@ class Settings(Singleton, SettingsREPMixin):
     def is_agent_config_enabled(self):
         return self.config.get("enable", True)
 
+    @cached_property
+    def is_rewriter_enabled(self):
+        return self.config.get("agent.python.rewrite")
+
     @cached_property
     def is_profiler_enabled(self):
         return self.config.get("agent.python.enable_profiler")
@@ -321,15 +337,27 @@ class Settings(Singleton, SettingsREPMixin):
         Initialize Heartbeat between Agent and SR if it has not been already initialized.
         """
         if self.heartbeat is None:
-            self.heartbeat = Heartbeat(self)
+            # Circular import
+            from contrast.agent.heartbeat import Heartbeat
+
+            self.heartbeat = Heartbeat()
             self.heartbeat.start()
 
+    def establish_server_settings_poll(self):
+        """
+        Initialize Server Settings poll between Agent and TS if it has not been already initialized.
+        """
+        if self.server_settings_poll is None:
+            # Circular import
+            from contrast.agent.server_settings_poll import ServerSettingsPoll
+
+            self.server_settings_poll = ServerSettingsPoll()
+            self.server_settings_poll.start()
+
     def process_responses(self, responses):
         """
         :param responses: list of Message responses from SR
         """
-        self.establish_heartbeat()
-
         logger.debug("Processing %s responses", len(responses))
 
         for response in responses:
@@ -403,9 +431,7 @@ class Settings(Singleton, SettingsREPMixin):
         Record server features received from teamserver (via the contrast service)
         Remove the rule_definitions field before logging because it's long and ugly
         """
-        if self.config.is_service_bypassed and isinstance(
-            server_features, ServerFeatures
-        ):
+        if isinstance(server_features, ServerFeatures):
             logger.debug(
                 "Received updated server features logFile=%s logLevel=%s Protect=%s Assess=%s",
                 server_features.log_file,
@@ -427,9 +453,36 @@ class Settings(Singleton, SettingsREPMixin):
     def code_exclusion_matchers(self):
         return [x for x in self.exclusion_matchers if x.is_code]
 
+    def load_exclusions_from_server(self, application_settings):
+        if (
+            hasattr(application_settings, "exclusions")
+            and application_settings.exclusions
+        ):
+            self.exclusions = Exclusions(
+                application_settings.exclusions,
+                self.is_protect_enabled(),
+                self.is_assess_enabled(),
+            )
+
+    def evaluate_exclusions(self, context, path):
+        if self.exclusions:
+            if self.exclusions.evaluate_url_exclusions(context, path):
+                # Stop analyzing this endpoint since the URL exclusion applies
+                return True
+
+            if self.exclusions.input_exclusions:
+                self.exclusions.set_input_exclusions_by_url(context, path)
+
+        return False
+
     def apply_ts_app_settings(self, response_json):
         self.direct_ts_app_settings = ApplicationSettings(response_json)
 
+        if self.direct_ts_app_settings.exclusions:
+            em = ExclusionMapper(self.direct_ts_app_settings.exclusions)
+
+            self.load_exclusions_from_server(em)
+
         # This is the only place session_id is set by TS.
         # If session id is set in the config, that value will be echoed back by TS
         if self.direct_ts_app_settings.session_id:
@@ -441,8 +494,14 @@ class Settings(Singleton, SettingsREPMixin):
 
         self.application_settings = data.application_settings
 
+        if self.application_settings.session_id:
+            self.config.session_id = self.application_settings.session_id
+
         ReactionProcessor.process(data.application_settings, self)
 
+        if not self.config.is_service_bypassed:
+            self.load_exclusions_from_server(self.application_settings)
+
         self.reset_transformed_settings()
 
         logger.debug(
@@ -613,25 +672,6 @@ class Settings(Singleton, SettingsREPMixin):
 
         return {}
 
-    @fail_loudly("Unable to ignore request", return_value=False)
-    def ignore_request(self, path):
-        """
-        Determine if the given path exactly matches any of the
-        configured url_exclusion_patterns.
-
-        :param path: path for current request
-        :return: bool whether the path matches any url_exclusion patterns
-        """
-        patterns = self.config.get("agent.python.url_exclusion_patterns")
-        if not patterns:
-            return False
-
-        for pattern in patterns:
-            if pattern.fullmatch(path):
-                logger.debug("Path %s matched on pattern %s", path, pattern)
-                return True
-        return False
-
     def update_sampling(self):
         server_sampling = (
             self.direct_teamserver_server_features.features.get("features")
