@@ -7,7 +7,7 @@ Functions for communication with speedracer to receive input analysis
 import contrast
 from contrast.agent import service_client
 from contrast.agent.settings import Settings
-from contrast.api.settings_pb2 import ProtectionRule
+from contrast.agent.protect.rule import ProtectionRule
 from contrast.utils.exceptions.security_exception import SecurityException
 
 from contrast.extern import structlog as logging
@@ -63,5 +63,4 @@ def create_activity_from_speedracer_input_analysis(speedracer_input_analysis, co
             attack = rule.build_attack_with_match(evaluation.value, evaluation)
         else:
             attack = rule.build_attack_without_match(evaluation=evaluation)
-        context.activity.results.extend([attack])
         context.attacks.append(attack)
