@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.api.dtm_pb2 import ArchitectureComponent as ArchCompDtm
 from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
@@ -21,28 +20,6 @@ class ArchitectureComponent(object):
             else (db_info.get("vendor") or "default")
         )
 
-    def to_dtm(self):
-        arch_comp = ArchCompDtm()
-        arch_comp.type = self.type
-        arch_comp.url = self.url
-
-        # vendor must be a string that exactly matches a value from
-        # Teamserver's flowmap/technologies.json > service > one of "name"
-        if self.db_info.get("vendor"):
-            arch_comp.vendor = self.db_info.get("vendor")
-
-        if self.db_info.get("host"):
-            arch_comp.remote_host = self.db_info.get("host")
-
-        if self.db_info.get("port"):
-            port = self.db_info.get("port")
-            try:
-                arch_comp.remote_port = int(port)
-            except ValueError:
-                arch_comp.remote_port = -1
-
-        return arch_comp
-
     def to_json(self):
         json = {
             "type": self.type,
