@@ -3,10 +3,10 @@
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.policy.loader import Policy
 from contrast.agent.assess.policy import trigger_policy
-from contrast.utils.decorators import fail_safely
+from contrast.utils.decorators import fail_quietly
 
 
-@fail_safely("Error running unsafe code execution assess rule")
+@fail_quietly("Error running unsafe code execution assess rule")
 def apply_rule(module_name, method_name, result, args, kwargs):
     if len(args) < 1:
         return
