@@ -45,17 +45,8 @@ PyObject *set_attr_on_type(PyObject *self, PyObject *args) {
     Py_RETURN_NONE;
 }
 
-PyObject *initialize(PyObject *self, PyObject *args, PyObject *kwargs) {
-    PyObject *logger = NULL;
+PyObject *initialize(PyObject *unused, PyObject *unused2) {
     funchook_t *funchook = NULL;
-    char *keywords[] = {"logger", NULL};
-
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|O", keywords, &logger)) {
-        /* Exception will propagate, no need to record to stderr */
-        return NULL;
-    }
-
-    set_logger(logger);
 
     log_debug("BUILD DATETIME %s ", EXTENSION_BUILD_TIME);
 
