@@ -37,7 +37,8 @@ typedef enum log_level
         PyErr_Format(exp, __VA_ARGS__); \
     } while (0);
 
-void set_logger(PyObject *_logger);
+PyObject *initialize_logger(PyObject *self, PyObject *args, PyObject *kwargs);
+
 void teardown_logger(void);
 void log_message_at_level(log_level_t level, const char *msg, ...);
 
