@@ -8,11 +8,17 @@
 
 #include <contrast/assess/patches.h>
 #include <contrast/assess/scope.h>
+#include <contrast/assess/intern.h>
+#include <contrast/assess/logging.h>
 
 static PyMethodDef methods[] = {
+    {"initialize_logger",
+     (PyCFunction)initialize_logger,
+     METH_VARARGS | METH_KEYWORDS,
+     "Initialize C extension logger"},
     {"initialize",
      (PyCFunction)initialize,
-     METH_VARARGS | METH_KEYWORDS,
+     METH_NOARGS,
      "Initialize C extension patcher"},
     {"enable_required_hooks",
      enable_required_hooks,
@@ -52,6 +58,7 @@ static PyMethodDef methods[] = {
      METH_NOARGS,
      "Initialize ContextVars used for scope"},
     {"set_attr_on_type", set_attr_on_type, METH_VARARGS, "Set attribute on type"},
+    {"is_string_interned", is_string_interned, METH_O, "Checkes if string is interned"},
     {NULL, NULL, 0, NULL}};
 
 static struct PyModuleDef cs_str_definition = {
