@@ -35,7 +35,13 @@ class BottleMiddleware(WSGIMiddleware):
         if not path:
             return None
         method = request.method
-        route_info = self.wsgi_app.match({"PATH_INFO": path, "REQUEST_METHOD": method})
+        try:
+            route_info = self.wsgi_app.match(
+                {"PATH_INFO": path, "REQUEST_METHOD": method}
+            )
+        except bottle.HTTPError:
+            return None
+
         if not route_info:
             return None
         view_func = route_info[0].callback
