@@ -224,6 +224,10 @@ class AgentConfig(object):
     def app_tags(self):
         return self.get("application.tags", "")
 
+    @property
+    def assess_tags(self):
+        return self.get("assess.tags", "")
+
     @cached_property
     def is_service_bypassed(self):
         bypass = self.get("agent.service.bypass", None)
@@ -239,7 +243,15 @@ class AgentConfig(object):
 
     @cached_property
     def is_request_audit_enabled(self):
-        return self.is_service_bypassed and self.get("api.request_audit.enable")
+        return self.get("api.request_audit.enable")
+
+    @cached_property
+    def application_activity_polling_interval(self):
+        return self.get("agent.polling.app_activity_ms", 30_000)
+
+    @cached_property
+    def server_settings_poll_interval(self):
+        return self.get("agent.polling.server_settings_ms", 30_000)
 
     @cached_property
     def teamserver_type(self):
@@ -347,6 +359,11 @@ class Agent(ConfigBuilder):
                 default_value=DEFAULT_PROGNAME,
                 type_cast=str,
             ),
+            ConfigOption(
+                name="python.rewrite",
+                default_value=True,
+                type_cast=utils.str_to_bool,
+            ),
             ConfigOption(
                 name="python.enable_drf_response_analysis",
                 default_value=True,
@@ -367,12 +384,6 @@ class Agent(ConfigBuilder):
                 default_value=False,
                 type_cast=utils.str_to_bool,
             ),
-            # TODO: PYT-837 remove this config once exclusions are implemented
-            ConfigOption(
-                name="python.url_exclusion_patterns",
-                default_value=[],
-                type_cast=utils.strs_to_regexes,
-            ),
             ConfigOption(
                 name="python.assess.use_pure_python_hooks",
                 default_value=False,
@@ -382,10 +393,7 @@ class Agent(ConfigBuilder):
                 name="polling.app_activity_ms", default_value=30000, type_cast=int
             ),
             ConfigOption(
-                name="polling.server_activity_ms", default_value=30000, type_cast=int
-            ),
-            ConfigOption(
-                name="polling.accumulated_rules_ms", default_value=30000, type_cast=int
+                name="polling.server_settings_ms", default_value=30_000, type_cast=int
             ),
             ConfigOption(
                 name="service.enable", default_value=True, type_cast=utils.str_to_bool
