@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright © 2021 Contrast Security, Inc.
+# Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 """
 Contains dependencies of the agent that we have chosen to vendor
@@ -10,7 +10,7 @@ it difficult for them to install our dependencies. By vendoring, we reduce the
 burden for them. Vendoring also allows ourselves to use specific, known stable
 versions of dependencies without worrying about conflicts in customer
 environments. This can be especially useful for common packages that are
-expected to already exist in most environments (e.g. `six`).
+expected to already exist in most environments (e.g. `ruamel.yaml`).
 
 The code under this directory should be ignored when linting and when
 calculating test coverage since it is technically out of our control. In
