@@ -3,16 +3,13 @@
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.wsgi.middleware import WSGIMiddleware
 from contrast.agent.middlewares.app_finder import get_original_app_or_fail
-from contrast.agent.middlewares.route_coverage.falcon_routes import (
-    create_falcon_routes,
-    get_view_method,
-    build_falcon_route,
-)
+from contrast.agent.middlewares.route_coverage.falcon_routes import FalconRoutesMixin
 from contrast.agent.assess.rules.config.falcon_secure_flag_rule import (
     FalconSecureFlagRule,
 )
 
-from contrast.utils.decorators import fail_safely, fail_quietly
+from contrast.utils.decorators import fail_quietly
+from contrast.utils.decorators import cached_property
 
 from contrast.extern import structlog as logging
 import falcon
@@ -20,7 +17,7 @@ import falcon
 logger = logging.getLogger("contrast")
 
 
-class FalconMiddleware(WSGIMiddleware):
+class FalconMiddleware(FalconRoutesMixin, WSGIMiddleware):
     def __init__(self, app, orig_falcon_api_instance=None):
         falcon_app = falcon.App if falcon.__version__ >= "3" else falcon.API
 
@@ -40,31 +37,14 @@ class FalconMiddleware(WSGIMiddleware):
         # Use common config to define an app name.
         super().__init__(_app, app_name="Falcon Application")
 
-    @fail_safely("Unable to get route coverage", return_value={})
-    def get_route_coverage(self):
-        return create_falcon_routes(self.falcon_app)
-
-    @fail_quietly("Unable to get Falcon view func")
-    def get_view_func(self, request):
-        if not self.request_path:
-            return None
-
-        route_info = self.falcon_app._router.find(self.request_path)
-        if not route_info:
-            return None
-
-        self.endpoint_cls, _, _, _ = route_info
-        view_func = get_view_method(self.endpoint_cls, request.method)
-        return view_func
-
-    @fail_safely("Unable to build route", return_value="")
-    def build_route(self, view_func, url):
-        return build_falcon_route(view_func, self.endpoint_cls)
-
-    @fail_safely("Failed to run config scanning rules")
-    def scan_configs(self):
+    @fail_quietly("Failed to run config scanning rules")
+    def _scan_configs(self):
         """
         Run config scanning rules for assess
         """
         for rule in self.config_rules:
             rule.apply(self.falcon_app.resp_options)
+
+    @cached_property
+    def name(self):
+        return "falcon"
