@@ -21,7 +21,7 @@ from contrast.agent.middlewares.route_coverage.common import build_route
 from contrast.agent.asgi import starlette_request_to_environ, track_scope_sources
 from contrast.extern import structlog as logging
 from contrast.utils.exceptions.security_exception import SecurityException
-from contrast.utils.decorators import cached_property, fail_safely, log_time_cm
+from contrast.utils.decorators import cached_property, fail_quietly, log_time_cm
 from contrast.utils.exceptions.contrast_service_exception import (
     ContrastServiceException,
 )
@@ -66,7 +66,8 @@ class FastApiMiddleware(BaseMiddleware, BaseHTTPMiddleware):
 
     async def call_without_agent_async(self, request: Request, call_next):
         super().call_without_agent()
-        return await call_next(request)
+        with scope_.contrast_scope():
+            return await call_next(request)
 
     async def call_with_agent(self, context, request: Request, call_next):
         scope = request.scope
@@ -102,11 +103,11 @@ class FastApiMiddleware(BaseMiddleware, BaseHTTPMiddleware):
             if self.settings.is_assess_enabled():
                 contrast.STRING_TRACKER.ageoff()
 
-    @fail_safely("Unable to get route coverage", return_value={})
+    @fail_quietly("Unable to get route coverage", return_value={})
     def get_route_coverage(self):
         return create_fastapi_routes(self.original_app)
 
-    @fail_safely("Unable to get FastAPI view func")
+    @fail_quietly("Unable to get FastAPI view func")
     def get_view_func(self, request):
         if not self.request_path:
             return None
@@ -124,7 +125,7 @@ class FastApiMiddleware(BaseMiddleware, BaseHTTPMiddleware):
         view_func = matching_routes[0].endpoint
         return view_func
 
-    @fail_safely("Unable to build route", return_value="")
+    @fail_quietly("Unable to build route", return_value="")
     def build_route(self, view_func, url):
         return build_route(url, view_func)
 
@@ -174,3 +175,7 @@ class FastApiMiddleware(BaseMiddleware, BaseHTTPMiddleware):
         context.activity.http_response.response_body_binary = ensure_binary(
             response.body or ""
         )
+
+    @cached_property
+    def name(self):
+        return "fastapi"
