@@ -52,8 +52,8 @@ def build_and_patch_read_method(io_type, method_name):
                 apply_stream_source(
                     method_name, result, __cs_self, result, args, kwargs
                 )
-        except Exception:
-            logger.exception("failed to propagate %s", method_name)
+        except Exception as ex:
+            _debug_log(method_name, ex)
 
         scope.exit_propagation_scope()
 
@@ -85,8 +85,8 @@ def build_and_patch_write_method(io_type, method_name):
             stream_propagator.propagate_stream_write(
                 method_name, preshift, __cs_self, result
             )
-        except Exception:
-            logger.exception("failed to propagate %s", method_name)
+        except Exception as ex:
+            _debug_log(method_name, ex)
 
         scope.exit_propagation_scope()
 
@@ -124,8 +124,8 @@ def build_and_patch_writelines(io_type, method_name):
                 args_list,
                 kwargs,
             )
-        except Exception:
-            logger.exception("failed to propagate %s", method_name)
+        except Exception as ex:
+            _debug_log(method_name, ex)
 
         scope.exit_propagation_scope()
 
@@ -134,6 +134,10 @@ def build_and_patch_writelines(io_type, method_name):
     patch_manager.patch(io_type, method_name, patched_func)
 
 
+def _debug_log(method_name, ex):
+    logger.debug("failed to propagate %s", method_name, exc_info=ex)
+
+
 def patch_getvalue(io_module):
     build_and_patch_read_method(io_module.StringIO, "getvalue")
     build_and_patch_read_method(io_module.BytesIO, "getvalue")
