@@ -48,8 +48,8 @@ def build_bytearray_join_patch(orig_method, patch_policy):
             propagator = JoinPropagator(node, preshift, result)
             if propagator.needs_propagation:
                 propagator.track_and_propagate(result)
-        except Exception:
-            logger.exception("failed to propagate bytearray.join")
+        except Exception as ex:
+            logger.debug("failed to propagate bytearray.join", exc_info=ex)
 
         scope.exit_contrast_scope()
 
@@ -78,8 +78,8 @@ def build_strtype_join_patch(orig_method, patch_policy):
             propagator = JoinPropagator(node, preshift, result)
             if propagator.needs_propagation:
                 propagator.track_and_propagate(result)
-        except Exception:
-            logger.exception("failed to propagate join")
+        except Exception as ex:
+            logger.debug("failed to propagate join", exc_info=ex)
 
         scope.exit_contrast_scope()
 
@@ -119,9 +119,9 @@ def build_str_format_patch(orig_method, patch_policy):
             if propagator.needs_propagation:
                 with scope.contrast_scope():
                     propagator.track_and_propagate(result)
-        except Exception:
+        except Exception as ex:
             with scope.propagation_scope():
-                logger.exception("failed to propagate str.format")
+                logger.debug("failed to propagate str.format", exc_info=ex)
 
         return result
 
@@ -159,9 +159,9 @@ def build_str_formatmap_patch(orig_method, patch_policy):
             if propagator.needs_propagation:
                 with scope.contrast_scope():
                     propagator.track_and_propagate(result)
-        except Exception:
+        except Exception as ex:
             with scope.propagation_scope():
-                logger.exception("failed to propagate str.format")
+                logger.debug("failed to propagate str.format", exc_info=ex)
 
         return result
 
@@ -191,9 +191,11 @@ def build_generic_strtype_patch(orig_method, patch_policy):
 
             if propagator.needs_propagation:
                 propagator.track_and_propagate(result)
-        except Exception:
+        except Exception as ex:
             name = orig_method.__class__.__name__
-            logger.exception("failed to propagate %s.%s", name, orig_method.__name__)
+            logger.debug(
+                "failed to propagate %s.%s", name, orig_method.__name__, exc_info=ex
+            )
 
         scope.exit_contrast_scope()
 
@@ -226,9 +228,11 @@ def build_track_without_new_event_patch(orig_method, patch_policy):
 
             if propagator.needs_propagation:
                 propagator.track_and_propagate(result)
-        except Exception:
+        except Exception as ex:
             name = orig_method.__class__.__name__
-            logger.exception("failed to propagate %s.%s", name, orig_method.__name__)
+            logger.debug(
+                "failed to propagate %s.%s", name, orig_method.__name__, exc_info=ex
+            )
 
         scope.exit_contrast_scope()
 
