@@ -5,6 +5,7 @@
 Implements a single API for instrumenting all dbapi2-compliant modules
 """
 import contrast
+from contrast.api.architecture_component import ArchitectureComponent
 from contrast.applies.sqli import apply_rule
 from contrast.utils.decorators import fail_quietly
 from contrast.utils.patch_utils import build_and_apply_patch
@@ -117,7 +118,7 @@ class Dbapi2Patcher(object):
                 """
                 Patch for dbapi_adapter.connection().cursor().execute*()
                 """
-                self._safe_append_dbinfo_to_context()
+                self._safe_create_arch_component_and_append_to_context()
                 return apply_rule(self._adapter_name, orig_func, args, kwargs)
 
             return patched_method
@@ -172,7 +173,7 @@ class Dbapi2Patcher(object):
                     self.init_dbinfo(connection, args, kwargs)
                     self._safe_instrument_connection(connection)
                     self._connect_called = True
-                self._safe_append_dbinfo_to_context()
+                self._safe_create_arch_component_and_append_to_context()
                 return connection
 
             return connect_patch
@@ -180,14 +181,15 @@ class Dbapi2Patcher(object):
         return build_connect_patch
 
     @fail_quietly("failed to add database information to context")
-    def _safe_append_dbinfo_to_context(self):
+    def _safe_create_arch_component_and_append_to_context(self):
         """
-        Add the given database information to context.activity
+        Create ArchComponent with the given database information and append to context.database_info
         """
         context = contrast.CS__CONTEXT_TRACKER.current()
         if not context:
             return
-        context.database_info.append(self.dbinfo)
+        arch_comp = ArchitectureComponent(self.dbinfo).to_json()
+        context.database_info.append(arch_comp)
 
 
 @fail_quietly("failed to instrument database adapter")
