@@ -5,7 +5,7 @@ from contrast.extern.wrapt import register_post_import_hook
 import sys
 from contrast.agent.policy import patch_manager
 from contrast.patches.databases import dbapi2
-from contrast.utils.decorators import fail_safely
+from contrast.utils.decorators import fail_quietly
 
 SQLITE3 = "sqlite3"
 PYSQLITE2_DBAPI2 = "pysqlite2.dbapi2"
@@ -13,7 +13,7 @@ VENDOR = "SQLite3"
 
 
 class Sqlite3Patcher(dbapi2.Dbapi2Patcher):
-    @fail_safely("failed to get database inventory information")
+    @fail_quietly("failed to get database inventory information")
     def init_dbinfo(self, connection, connect_args, connect_kwargs):
         # sqlite does not use a server, so no need for host/port
         database = connect_kwargs.get("database") or (
