@@ -20,13 +20,13 @@ from contrast.utils.patch_utils import build_and_apply_patch
 from contrast.applies.assess.unsafe_code_execution import (
     apply_rule as apply_unsafe_code_exec_rule,
 )
-from contrast.utils.decorators import fail_safely
+from contrast.utils.decorators import fail_quietly
 
 
 INSTRUMENTED_FRAME_DEPTH = 1
 
 
-@fail_safely("Error applying rule for exec/eval patch")
+@fail_quietly("Error applying rule for exec/eval patch")
 def apply_rule(rule_applicator, orig_func, result, args, kwargs):
     context = contrast.CS__CONTEXT_TRACKER.current()
     if not (context and context.propagate_assess):
@@ -36,7 +36,7 @@ def apply_rule(rule_applicator, orig_func, result, args, kwargs):
         rule_applicator("BUILTIN", orig_func.__name__, result, args, kwargs)
 
 
-@fail_safely("Error running path traversal assess rule")
+@fail_quietly("Error running path traversal assess rule")
 def apply_pt_rule(module, method, result, args, kwargs):
     policy = Policy()
     trigger_rule = policy.triggers["path-traversal"]
