@@ -10,20 +10,22 @@ from contrast.agent.policy import patch_manager
 from contrast.agent.policy.applicator import apply_assess_patch
 from contrast.agent.policy.loader import Policy
 from contrast.patches import urllib_patch
-from contrast.utils.decorators import fail_safely
+from contrast.utils.decorators import fail_quietly
 from contrast.utils.patch_utils import build_and_apply_patch
 
+PYRAMID_SESSION_MODULE = "pyramid.session"
 
-@fail_safely("Failed to apply policy to new session class")
+
+@fail_quietly("Failed to apply policy to new session class")
 def _apply_policy(session_cls):
     policy = Policy()
 
-    for patch_policy in policy.policy_by_module["pyramid.session"]:
+    for patch_policy in policy.policy_by_module[PYRAMID_SESSION_MODULE]:
         if patch_policy.class_name == "CookieSession":
             apply_assess_patch(session_cls, patch_policy)
 
 
-@fail_safely("Failed to apply assess policy for BaseCookieSessionFactory")
+@fail_quietly("Failed to apply assess policy for BaseCookieSessionFactory")
 def _apply_assess(result, args, kwargs):
     context = contrast.CS__CONTEXT_TRACKER.current()
 
@@ -33,10 +35,10 @@ def _apply_assess(result, args, kwargs):
     analyze(context, patch_policy, result, args, kwargs)
 
 
-def build_BaseCookieSessionFactory_patch(orig_func, patch_policy):
-    def BaseCookieSessionFactory(*args, **kwargs):
+def build_base_cookie_session_factory_patch(orig_func, patch_policy):
+    def base_cookie_session_factory(*args, **kwargs):
         """
-        BaseCookieSessionFactory is a function that returns a new CookieSession class
+        base_cookie_session_factory is a function that returns a new CookieSession class
 
         Since we can't instrument the new class directly using normal policy machinery,
         we instead apply our policy on-demand to the newly created class.
@@ -51,14 +53,14 @@ def build_BaseCookieSessionFactory_patch(orig_func, patch_policy):
 
         return session_cls
 
-    return BaseCookieSessionFactory
+    return base_cookie_session_factory
 
 
 def patch_session_pyramid(pyramid_session_module):
     build_and_apply_patch(
         pyramid_session_module,
         "BaseCookieSessionFactory",
-        build_BaseCookieSessionFactory_patch,
+        build_base_cookie_session_factory_patch,
     )
 
 
@@ -78,12 +80,12 @@ def patch_encode_pyramid(pyramid_encode_module):
 
 
 def register_patches():
-    register_post_import_hook(patch_session_pyramid, "pyramid.session")
+    register_post_import_hook(patch_session_pyramid, PYRAMID_SESSION_MODULE)
     register_post_import_hook(patch_encode_pyramid, "pyramid.encode")
 
 
 def reverse_patches():
-    pyramid_session = sys.modules.get("pyramid.session")
+    pyramid_session = sys.modules.get(PYRAMID_SESSION_MODULE)
     pyramid_encode = sys.modules.get("pyramid.encode")
 
     if pyramid_session:
