@@ -9,11 +9,11 @@ from contrast.agent.assess.policy.preshift import Preshift
 from contrast.agent.assess.policy.analysis import _analyze
 from contrast.agent.policy import patch_manager
 from contrast.agent.policy.loader import Policy
-from contrast.utils.decorators import fail_safely
+from contrast.utils.decorators import fail_quietly
 from contrast.utils.patch_utils import build_and_apply_patch
 
 
-@fail_safely("Failed to apply assess xpath-injection")
+@fail_quietly("Failed to apply assess xpath-injection")
 def apply_assess(location, self, retval, args, kwargs):
     policy = Policy()
     patch_policy = policy.policy_by_name.get(location)
@@ -71,24 +71,24 @@ def create_instrumented_xpath_element_evaluator(XPathElementEvaluator):
     return ContrastXPathElementEvaluator
 
 
-def create_instrumented_xpath_document_evaluator(XPathDocumentEvaluator):
+def create_instrumented_xpath_document_evaluator(x_path_document_evaluator):
     """
     Generate instrumented subclass of XPathDocumentEvaluator
 
     See docstring for create_instrumented_xpath_element_evaluator above.
     """
 
-    class ContrastXPathDocumentEvaluator(XPathDocumentEvaluator):
+    class ContrastXPathDocumentEvaluator(x_path_document_evaluator):
         def __call__(__cs_self, *args, **kwargs):
             orig_func = super().__call__
             return apply_call(
-                XPathDocumentEvaluator.__name__, orig_func, __cs_self, args, kwargs
+                x_path_document_evaluator.__name__, orig_func, __cs_self, args, kwargs
             )
 
     return ContrastXPathDocumentEvaluator
 
 
-def create_instrumented_xpath(XPath):
+def create_instrumented_xpath(x_path):
     """
     Generate instrumented subclass of XPath
 
@@ -97,29 +97,36 @@ def create_instrumented_xpath(XPath):
     it's safe to make a reference to the original type.
     """
 
-    class ContrastXPath(XPath):
+    class ContrastXPath(x_path):
         def __init__(__cs_self, *args, **kwargs):
             try:
                 super().__init__(*args, **kwargs)
+            except TypeError:
+                # See PYT-2364.
+                # Calling inheritance in this *bad* way fixes a TypeError raised
+                # from lxml.cssselect.CSSSelector.__init__ calling
+                # etree.XPath.__init__(self, ...)
+                # instead of using super()
+                x_path.__init__(__cs_self, *args, **kwargs)
             finally:
                 apply_assess("lxml.etree.XPath.__init__", __cs_self, None, args, kwargs)
 
     return ContrastXPath
 
 
-def build_XPathEvaluator_patch(orig_func, _):
-    def XPathEvaluator(*args, **kwargs):
+def build_x_path_eval_patch(orig_func, _):
+    def x_path_evaluator(*args, **kwargs):
         """
         Instrumented version of XPathEvaluator factory
         """
         evaluator = orig_func(*args, **kwargs)
         return ContrastXPathEvaluatorProxy(evaluator)
 
-    return XPathEvaluator
+    return x_path_evaluator
 
 
 def patch_etree(etree_module):
-    build_and_apply_patch(etree_module, "XPathEvaluator", build_XPathEvaluator_patch)
+    build_and_apply_patch(etree_module, "XPathEvaluator", build_x_path_eval_patch)
 
     new_xpath = create_instrumented_xpath(etree_module.XPath)
     patch_manager.patch(etree_module, "XPath", new_xpath)
