@@ -11,7 +11,7 @@ from contrast.agent.policy import patch_manager
 from contrast.agent.policy.applicator import apply_module_patches
 from contrast.agent.scope import pop_contrast_scope
 from contrast.assess_extensions import smart_setattr
-from contrast.utils.decorators import fail_safely
+from contrast.utils.decorators import fail_quietly
 from contrast.utils.patch_utils import repatch_module
 
 
@@ -40,7 +40,7 @@ def is_wrapped_staticmethod(obj):
     return isinstance(obj, staticmethod) and hasattr(obj.__func__, "__wrapped__")
 
 
-@fail_safely("Failed to apply pathlib patches")
+@fail_quietly("Failed to apply pathlib patches")
 def patch_pathlib(pathlib_module):
     """
     Apply patches to the pathlib module
