@@ -20,12 +20,15 @@ from contrast.agent.policy.loader import Policy
 from contrast.agent.assess.apply_trigger import cs__apply_trigger
 from contrast.agent.assess.policy.analysis import analyze
 from contrast.agent.assess.policy.propagators import regex_propagator
-from contrast.utils.decorators import fail_safely
+from contrast.utils.decorators import fail_quietly
 from contrast.utils.patch_utils import build_and_apply_patch
 from contrast.utils.string_utils import ensure_string
 
 logger = logging.getLogger("contrast")
 
+PATTERN_CLASS = "re.Pattern"
+MATCH_CLASS = "re.Match"
+
 
 def build_group_hook(original_func, patch_policy, propagator):
     def group_hook(*args, **kwargs):
@@ -56,7 +59,7 @@ def get_propagation_node(node):
     return node.propagator_nodes[0] if node.propagator_nodes else None
 
 
-@fail_safely("Failed to propagate sub(n)")
+@fail_quietly("Failed to propagate sub(n)")
 def _analyze_sub(node, retval, repl_results, args, kwargs, new_args):
     if node.method_name == "subn":
         result, count = retval
@@ -79,7 +82,7 @@ def _analyze_sub(node, retval, repl_results, args, kwargs, new_args):
         )
 
 
-@fail_safely("Failed to analyze redos trigger")
+@fail_quietly("Failed to analyze redos trigger")
 def _trigger_redos(name, result, args, kwargs):
     context = contrast.CS__CONTEXT_TRACKER.current()
     if context is None:
@@ -122,7 +125,7 @@ def _trigger_redos(name, result, args, kwargs):
 def _get_redos_trigger_node(trigger_name, rule):
     trigger_loc = "re"
     if "Pattern" in trigger_name:
-        trigger_loc = "re.Pattern"
+        trigger_loc = PATTERN_CLASS
 
     func_name = trigger_name.split(".")[-1]
     trigger_nodes = rule.find_trigger_nodes(trigger_loc, func_name)
@@ -193,7 +196,7 @@ def build_sub_hook(original_func, policy_node):
     return sub_hook
 
 
-@fail_safely("Failed to analyze")
+@fail_quietly("Failed to analyze")
 def _analyze_policy(name, result, args, kwargs):
     context = contrast.CS__CONTEXT_TRACKER.current()
     if context is None or not context.propagate_assess:
@@ -247,42 +250,42 @@ def patch_re(re_module):
     build_and_apply_patch(re_module, "sub", build_sub_hook)
     build_and_apply_patch(re_module, "subn", build_sub_hook)
 
-    build_and_apply_patch(pattern_cls, "sub", build_sub_hook, owner_name="re.Pattern")
-    build_and_apply_patch(pattern_cls, "subn", build_sub_hook, owner_name="re.Pattern")
+    build_and_apply_patch(pattern_cls, "sub", build_sub_hook, owner_name=PATTERN_CLASS)
+    build_and_apply_patch(pattern_cls, "subn", build_sub_hook, owner_name=PATTERN_CLASS)
     build_and_apply_patch(
         pattern_cls,
         "split",
         build_re_assess_hook,
-        owner_name="re.Pattern",
+        owner_name=PATTERN_CLASS,
     )
     build_and_apply_patch(
         pattern_cls,
         "findall",
         build_re_assess_hook,
-        owner_name="re.Pattern",
+        owner_name=PATTERN_CLASS,
     )
 
     build_and_apply_patch(
         pattern_cls,
         "match",
         build_re_pattern_redos_hook,
-        owner_name="re.Pattern",
+        owner_name=PATTERN_CLASS,
     )
     build_and_apply_patch(
         pattern_cls,
         "search",
         build_re_pattern_redos_hook,
-        owner_name="re.Pattern",
+        owner_name=PATTERN_CLASS,
     )
     build_and_apply_patch(
-        pattern_cls, "finditer", build_re_pattern_redos_hook, owner_name="re.Pattern"
+        pattern_cls, "finditer", build_re_pattern_redos_hook, owner_name=PATTERN_CLASS
     )
 
     build_and_apply_patch(
         pattern_cls,
         "fullmatch",
         build_re_pattern_redos_hook,
-        owner_name="re.Pattern",
+        owner_name=PATTERN_CLASS,
     )
 
     build_and_apply_patch(
@@ -290,21 +293,21 @@ def patch_re(re_module):
         "group",
         build_group_hook,
         (regex_propagator.propagate_group,),
-        owner_name="re.Match",
+        owner_name=MATCH_CLASS,
     )
     build_and_apply_patch(
         match_cls,
         "groups",
         build_group_hook,
         (regex_propagator.propagate_groups,),
-        owner_name="re.Match",
+        owner_name=MATCH_CLASS,
     )
     build_and_apply_patch(
         match_cls,
         "groupdict",
         build_group_hook,
         (regex_propagator.propagate_groupdict,),
-        owner_name="re.Match",
+        owner_name=MATCH_CLASS,
     )
 
 
