@@ -9,7 +9,7 @@ from contrast.reporting.teamserver_messages import BaseTsMessage
 from requests.models import Response
 
 from contrast.extern import structlog as logging
-from contrast.utils.decorators import fail_safely
+from contrast.utils.decorators import fail_quietly
 
 logger = logging.getLogger("contrast")
 
@@ -17,9 +17,8 @@ logger = logging.getLogger("contrast")
 def get_message_body(msg):
     if isinstance(msg, BaseTsMessage):
         return msg.body
-    if isinstance(msg, Response):
-        if msg.status_code == 200:
-            return msg.json()
+    if isinstance(msg, Response) and msg.status_code == 200:
+        return msg.json()
 
     return {}
 
@@ -31,7 +30,7 @@ class RequestAudit(object):
         self.config = config
         self.messages_path = ""
 
-    @fail_safely("Unable to prepare request_audit dirs")
+    @fail_quietly("Unable to prepare request_audit dirs")
     def prepare_dirs(self):
         # grab config request audit path, or the default, write /messages dir
         # create requests/response subdirs under message
@@ -55,7 +54,7 @@ class RequestAudit(object):
         if self.config.get("api.request_audit.responses"):
             self.write_data(response, "responses", msg.name)
 
-    @fail_safely("Unable to write request audit data")
+    @fail_quietly("Unable to write request audit data")
     def write_data(self, msg, msg_type, msg_name):
         now = datetime.now()
         epoch = now.timestamp()
