@@ -10,8 +10,6 @@ import contrast
 from contrast.agent.disable_reaction import DisableReaction
 from contrast.agent.settings import Settings
 from contrast.api import dtm_pb2
-from contrast.api.architecture_component import ArchitectureComponent
-from contrast.api.attack import Attack
 from contrast.utils.timer import now_ms
 from contrast.utils.decorators import fail_loudly
 from contrast.utils.object_utils import NOTIMPLEMENTED_MSG
@@ -200,7 +198,7 @@ class ServerActivity(BaseServerMsg):
 
     @property
     def name(self):
-        return "activity_server"
+        return "activity-server"
 
     @property
     def path(self):
@@ -255,11 +253,11 @@ class ServerStart(BaseServerMsg):
 
     @property
     def name(self):
-        return "agent_startup"
+        return "agent-startup"
 
     @property
     def path(self):
-        return "/servers/"
+        return "servers/"
 
     @property
     def expected_response_codes(self):
@@ -298,13 +296,14 @@ class BaseTsAppMessage(BaseTsMessage):
 
 
 class Preflight(BaseTsAppMessage):
-    def __init__(self, activity):
+    def __init__(self, findings, http_request):
         super().__init__()
 
-        self.activity = activity
+        self.findings = findings
+        self.http_request = http_request
 
         self.body = {"messages": []}
-        for idx, finding in enumerate(self.activity.findings):
+        for idx, finding in enumerate(self.findings):
             message = {
                 "appLanguage": PYTHON,
                 "appName": self.settings.app_name,
@@ -340,8 +339,8 @@ class Preflight(BaseTsAppMessage):
         body = response.text
         finding_idxs_to_report = self._parse_body(body)
         for finding_idx in finding_idxs_to_report:
-            finding = self.activity.findings[finding_idx]
-            traces_msg = _Traces(finding, self.activity.http_request)
+            finding = self.findings[finding_idx]
+            traces_msg = _Traces(finding, self.http_request)
             reporting_client.add_message(traces_msg)
 
     @staticmethod
@@ -363,6 +362,7 @@ class _Traces(BaseTsAppMessage):
         super().__init__()
 
         self.headers.update({"Report-Hash": finding.preflight.split(",")[-1]})
+
         self.body = self._build_body(finding, request)
 
     @property
@@ -383,87 +383,13 @@ class _Traces(BaseTsAppMessage):
 
     def _build_body(self, finding, request: dtm_pb2.HttpRequest):
         path, _, querystring = request.raw.partition("?")
+
         return {
             "created": (
                 finding.events[-1].timestamp_ms if len(finding.events) > 0 else now_ms()
             ),
-            "events": [
-                {
-                    "action": EVENT_ACTION_LOOKUP[event.action],
-                    "args": [
-                        {
-                            # "hash": 0,  # not required
-                            "tracked": arg.tracked,
-                            "value": arg.value,
-                        }
-                        for arg in event.args
-                    ],
-                    # "code": "string",  # currently unused; maybe useful in the future
-                    "eventSources": [
-                        {
-                            "sourceName": s.name,
-                            "sourceType": s.type,
-                        }
-                        for s in event.event_sources
-                    ],
-                    "fieldName": event.field_name,
-                    "object": {
-                        # "hash": 0,  # not required
-                        "tracked": event.object.tracked,
-                        "value": event.object.value,
-                    },
-                    "objectId": event.object_id,
-                    "parentObjectIds": [{"id": p.id} for p in event.parent_object_ids],
-                    # properties not used for dataflow rules
-                    # "properties": [{"key": "string", "value": "string"}],
-                    "ret": {
-                        # "hash": 0,  # not required
-                        "tracked": event.ret.tracked,
-                        "value": event.ret.value,
-                    },
-                    "signature": {
-                        "argTypes": list(event.signature.arg_types),
-                        "className": event.signature.class_name,
-                        "constructor": event.signature.constructor,
-                        # not required and we don't save this to the DTM
-                        # "expressionType": "MEMBER_EXPRESSION",
-                        # "flags": 0,  # java only
-                        "methodName": event.signature.method_name,
-                        # not required and we don't save this to the DTM
-                        # "operator": "string",
-                        "returnType": event.signature.return_type,
-                        # "signature": "string",  # deprecated
-                        "voidMethod": event.signature.void_method,
-                    },
-                    "source": event.source,
-                    "stack": [
-                        {
-                            "eval": s.eval,
-                            "file": s.file_name,
-                            "lineNumber": s.line_number,
-                            "method": s.method_name,
-                            "signature": s.signature,
-                            "type": s.type,
-                        }
-                        for s in event.stack
-                    ],
-                    # "tags": "string",  # we don't save this to the DTM
-                    "taintRanges": [
-                        {
-                            "tag": t.tag,
-                            "range": t.range,
-                        }
-                        for t in event.taint_ranges
-                    ],
-                    "target": event.target,
-                    # "thread": "string",  # not required
-                    "time": event.timestamp_ms,
-                    "type": EVENT_TYPE_LOOKUP[event.type],
-                }
-                for event in finding.events
-            ],
-            # "evidence": "string",  # deprecated
-            "properties": dict(finding.properties),
+            "events": [event.to_json() for event in finding.events],
+            "properties": finding.properties,
             "request": {
                 "body": ensure_string(request.request_body_binary),
                 # the WSGI environ supports only one value per request header. However
@@ -482,17 +408,10 @@ class _Traces(BaseTsAppMessage):
                 "uri": path,
                 "version": request.version,
             },
-            "routes": [
-                {
-                    "count": r.count,
-                    "observations": [{"url": r.url, "verb": r.verb}],
-                    "signature": r.route,
-                }
-                for r in finding.routes
-            ],
+            "routes": [route.to_json_traces() for route in finding.routes],
             "ruleId": finding.rule_id,
             "session_id": self.settings.config.session_id,
-            "tags": finding.tags,
+            "tags": self.settings.config.assess_tags,
             "version": finding.version,
         }
 
@@ -517,7 +436,7 @@ class ObservedRoute(BaseTsAppMessage):
 
     @property
     def name(self):
-        return "observed_route"
+        return "observed-route"
 
     @property
     def path(self):
@@ -566,7 +485,7 @@ class ApplicationUpdate(BaseTsAppMessage):
 
     @property
     def name(self):
-        return "update_application"
+        return "update-application"
 
     @property
     def path(self):
@@ -589,7 +508,7 @@ class ApplicationInventory(BaseTsAppMessage):
         self.base_url = f"{self.settings.api_url}/agents/v1.0/"
 
         self.body = {
-            "routes": [route.to_json() for route in routes.values()],
+            "routes": [route.to_json_inventory() for route in routes.values()],
         }
 
         session_id = self.settings.config.session_id
@@ -784,17 +703,19 @@ class Activity(BaseTsAppMessage):
             self.body["inventory"]["browsers"] = [context.request.user_agent]
         if context.database_info:
             for db_info in context.database_info:
-                arch_comp = ArchitectureComponent(db_info).to_json()
-                self.body["inventory"]["components"].append(arch_comp)
+                self.body["inventory"]["components"].append(db_info)
 
         if context.attacks:
             self.body["defend"] = {"attackers": []}
 
-            for attack_dtm in context.attacks:
-                attack = Attack(attack_dtm, context.activity.http_request).to_json()
+            for attack in context.attacks:
                 self.body["defend"]["attackers"].append(
                     {
-                        "protectionRules": {attack_dtm.rule_id: attack},
+                        "protectionRules": {
+                            attack.rule_id: attack.to_json(
+                                context.activity.http_request
+                            )
+                        },
                         "source": {
                             "ip": context.request.client_addr or "",
                             "xForwardedFor": context.request.headers.get(
