@@ -2,14 +2,13 @@
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import os
-import re
 import socket
 
 from contrast import AGENT_CURR_WORKING_DIR
 from contrast.utils.string_utils import truncate
 from contrast.extern.ruamel import yaml
 
-from contrast.api.settings_pb2 import ProtectionRule
+from contrast.agent.protect.rule import ProtectionRule
 
 from contrast.extern import structlog as logging
 
@@ -167,27 +166,6 @@ def parse_disabled_rules(disabled_rules):
     return [rule.lower() for rule in disabled_rules.split(",")]
 
 
-def strs_to_regexes(patterns):
-    """
-
-    :param patterns: list of strings
-    :return: list of regular expressions
-    """
-    if not patterns:
-        return []
-
-    regexes = []
-
-    for pattern in patterns:
-        try:
-            pat = re.compile(pattern)
-            regexes.append(pat)
-        except Exception as ex:
-            logger.warning("Unable to parse pattern %s: %s", pattern, ex)
-
-    return regexes
-
-
 def parse_stacktraces_options(option):
     option = option.upper()
     if option in STACKTRACE_OPTIONS:
