@@ -1,32 +1,50 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2022 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
+import os
 from contextlib import contextmanager
 import logging as stdlib_logging
 
+import contrast
 from contrast.utils.exceptions.security_exception import SecurityException
 from contrast.utils.timer import now_ms_float
 from contrast.utils.loggers import TRACE_LEVEL
 from contrast.extern import structlog as logging
+from contrast.agent.validator import ValidationException
 
 logger = logging.getLogger("contrast")
 
 DEBUG_LEVEL = stdlib_logging.DEBUG
 
 
-def _log_extra_safely(log_message, error, args, kwargs, log_level="debug"):
+def _log_extra_safely(
+    log_message: str, error: Exception, original_func, args, kwargs, log_level="debug"
+):
+    if not contrast.telemetry_disabled():
+        TELEMETRY = contrast.TELEMETRY
+    else:
+        TELEMETRY = None
+
     try:
-        getattr(logger, log_level)(log_message + ": " + str(error))
+        full_msg = log_message + ": " + str(error)
+        getattr(logger, log_level)(full_msg, exc_info=error)
         logger.debug("wrapped function args: %s", args)
         logger.debug("wrapped function kwargs: %s", kwargs)
+
+        if TELEMETRY is not None:
+            TELEMETRY.report_error(
+                error=error, original_func=original_func, message=full_msg
+            )
+    except ValidationException as val_ex:
+        logger.debug(f"Cannot report error to Telemetry: {str(val_ex)}")
     except Exception:
-        # For complete safety, we're not going to try to log the logging erro
+        # For complete safety, we're not going to try to log the logging error
         # because sometimes the logging error is actually an error (such as a recursive
         # error) within the logging module itself!
         pass
 
 
-def fail_safely(log_message, log_level="exception", return_value=None):
+def fail_loudly(log_message, log_level="exception", return_value=None):
     """
     Decorator that will run the decorated function/method and, if
     an exception is raised, return a safe value and log the error.
@@ -45,8 +63,13 @@ def fail_safely(log_message, log_level="exception", return_value=None):
                 return original_func(*args, **kwargs)
             except SecurityException:
                 raise
-            except Exception as e:
-                _log_extra_safely(log_message, e, args, kwargs, log_level)
+            except Exception as ex:
+                _log_extra_safely(
+                    log_message, ex, original_func, args, kwargs, log_level
+                )
+                if os.environ.get("CONTRAST_TESTING"):
+                    raise
+
             return return_value
 
         return run_safely
@@ -126,7 +149,7 @@ def log_time_cm(log_message):
 
 def fail_quietly(log_message, return_value=None):
     """
-    Similar to fail_safely (see above)
+    Similar to fail_loudly (see above)
 
     This decorator is intended to handle cases where an exception may occur but won't
     disrupt normal operation of the agent. This decorator should be used to protect
@@ -142,9 +165,10 @@ def fail_quietly(log_message, return_value=None):
                 return original_func(*args, **kwargs)
             except SecurityException:
                 raise
-            except Exception as e:
-                _log_extra_safely(log_message, e, args, kwargs)
-
+            except Exception as ex:
+                _log_extra_safely(log_message, ex, original_func, args, kwargs)
+                if os.environ.get("CONTRAST_TESTING"):
+                    raise
             return return_value
 
         return run_safely
