@@ -15,4 +15,4 @@ class Digest(object):
         if not value:  # None or empty string
             return
 
-        self.crc32 = zlib.crc32(value.encode(), self.crc32)
+        self.crc32 = zlib.crc32(str(value).encode(), self.crc32)
