@@ -4,9 +4,6 @@
 import os
 import hashlib
 
-import pkg_resources
-from contrast.agent import scope
-
 CONTRAST_AGENT_DIST = "contrast-agent"
 
 # Both of these metadata files contain a file list of what is installed under the top level dirs
@@ -49,17 +46,6 @@ def normalize_file_name(file_path):
     return normalized_file_name
 
 
-def get_installed_distributions():
-    """
-    Wrapper used to get list of installed distributions in current active environment.
-    """
-    with scope.contrast_scope():
-        return [
-            d
-            for d in pkg_resources.working_set  # pylint: # pylint: disable=not-an-iterable
-        ]
-
-
 def _parse_top_level_dirs_from_manifest_file(dist, namespace, metadata_filename):
     """
     @param dist: Distribution object used to check to see what
