@@ -60,11 +60,6 @@ def setup_agent_logger(config):
 
     cs_str.initialize_logger(structlog.getLogger(LOGGER_NAME))
 
-    # print so it shows up in STDOUT
-    print(
-        f"Contrast Agent Logger Initialized: {logging.getLevelName(logger.level)} : {path}"
-    )  # pylint: disable=superfluous-parens
-
 
 def reset_agent_logger(log_path, log_level):
     """
