@@ -4,6 +4,8 @@
 import copy
 from inspect import isclass
 
+NOTIMPLEMENTED_MSG = "This method should be implemented by concrete subclass subclass"
+
 
 def safe_copy(value):
     """
@@ -14,7 +16,7 @@ def safe_copy(value):
     """
     try:
         return copy.copy(value)
-    except:
+    except Exception:
         return value
 
 
