@@ -84,11 +84,21 @@ def protobuf_safe(value):
     return "" if value is None else value
 
 
-def ensure_string(s, encoding="utf-8", errors="ignore"):
-    if not isinstance(s, (str, bytes)):
-        raise TypeError(f"not expecting type {type(s)}")
+def ensure_string(value, encoding="utf-8", errors="ignore"):
+    """
+    Convert `value` of any type to a string, even if empty string.
+    """
+    if isinstance(value, str):
+        return value
+    if isinstance(value, bytes):
+        return value.decode(encoding, errors)
 
-    return s if isinstance(s, str) else s.decode(encoding, errors)
+    # Check to see if value can be made a str
+    try:
+        return str(value)
+    except Exception:
+        pass
+    return ""
 
 
 def ensure_binary(s, encoding="utf-8", errors="ignore"):
